Class: CropwisePlatformSdk::AccountInvitation

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/models/account_invitation.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccountInvitation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::AccountInvitation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::AccountInvitation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'login')
    self. = attributes[:'login']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'authorities')
    if (value = attributes[:'authorities']).is_a?(Array)
      self.authorities = value
    end
  end

  if attributes.key?(:'by_concierge')
    self.by_concierge = attributes[:'by_concierge']
  end

  if attributes.key?(:'redirect_uri')
    self.redirect_uri = attributes[:'redirect_uri']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  end
end

Instance Attribute Details

#authoritiesObject

Returns the value of attribute authorities.



31
32
33
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 31

def authorities
  @authorities
end

#by_conciergeObject

Returns the value of attribute by_concierge.



33
34
35
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 33

def by_concierge
  @by_concierge
end

#client_idObject

Mandatory when ‘redirect_uri` is present



38
39
40
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 38

def client_id
  @client_id
end

#emailObject

Either ‘email` or `login` must be present



19
20
21
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 19

def email
  @email
end

#localeObject

Returns the value of attribute locale.



40
41
42
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 40

def locale
  @locale
end

#loginObject

Either ‘email` or `login` must be present



22
23
24
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 22

def 
  @login
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 24

def name
  @name
end

#passwordObject

Mandatory when ‘login` is sent instead of `email`



27
28
29
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 27

def password
  @password
end

#redirect_uriObject

Returns the value of attribute redirect_uri.



35
36
37
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 35

def redirect_uri
  @redirect_uri
end

#roleObject

Returns the value of attribute role.



29
30
31
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 29

def role
  @role
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 65

def self.attribute_map
  {
    :'email' => :'email',
    :'login' => :'login',
    :'name' => :'name',
    :'password' => :'password',
    :'role' => :'role',
    :'authorities' => :'authorities',
    :'by_concierge' => :'by_concierge',
    :'redirect_uri' => :'redirect_uri',
    :'client_id' => :'client_id',
    :'locale' => :'locale'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 239

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



108
109
110
111
112
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 108

def self.openapi_all_of
  [
  :'AccountInvitationAllOf'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 86

def self.openapi_types
  {
    :'email' => :'String',
    :'login' => :'String',
    :'name' => :'String',
    :'password' => :'String',
    :'role' => :'String',
    :'authorities' => :'Array<Authority>',
    :'by_concierge' => :'Boolean',
    :'redirect_uri' => :'String',
    :'client_id' => :'String',
    :'locale' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
       == o. &&
      name == o.name &&
      password == o.password &&
      role == o.role &&
      authorities == o.authorities &&
      by_concierge == o.by_concierge &&
      redirect_uri == o.redirect_uri &&
      client_id == o.client_id &&
      locale == o.locale
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 270

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CropwisePlatformSdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 341

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 246

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 232

def hash
  [email, , name, password, role, authorities, by_concierge, redirect_uri, client_id, locale].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 174

def list_invalid_properties
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @locale.nil?
    invalid_properties.push('invalid value for "locale", locale cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 317

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



311
312
313
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 311

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
195
# File 'lib/cropwise-platform-sdk/models/account_invitation.rb', line 189

def valid?
  return false if @email.nil?
  return false if @locale.nil?
  locale_validator = EnumAttributeValidator.new('String', ["bg", "da", "de", "el", "en", "en_GB", "es", "es_419", "fr", "hi", "hu", "ja", "nl", "pl", "pt_BR", "ro", "sv", "uk"])
  return false unless locale_validator.valid?(@locale)
  true
end