Class: CropwisePlatformSdk::AccountManagementApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/api/account_management_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AccountManagementApi

Returns a new instance of AccountManagementApi.



19
20
21
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#post_accounts_recovery_recovery_id(recovery_id, opts = {}) ⇒ nil

Apply password change Apply the password change using a ‘recovery_id`.

Parameters:

  • recovery_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_password_update (AccountPasswordUpdate)

    Represents a **new password** to be associated with an `Account`.

Returns:

  • (nil)


28
29
30
31
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 28

def post_accounts_recovery_recovery_id(recovery_id, opts = {})
  post_accounts_recovery_recovery_id_with_http_info(recovery_id, opts)
  nil
end

#post_accounts_recovery_recovery_id_with_http_info(recovery_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Apply password change Apply the password change using a &#x60;recovery_id&#x60;.

Parameters:

  • recovery_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_password_update (AccountPasswordUpdate)

    Represents a **new password** to be associated with an &#x60;Account&#x60;.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 39

def post_accounts_recovery_recovery_id_with_http_info(recovery_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountManagementApi.post_accounts_recovery_recovery_id ...'
  end
  # verify the required parameter 'recovery_id' is set
  if @api_client.config.client_side_validation && recovery_id.nil?
    fail ArgumentError, "Missing the required parameter 'recovery_id' when calling AccountManagementApi.post_accounts_recovery_recovery_id"
  end
  # resource path
  local_var_path = '/v2/accounts/recovery/{recovery_id}'.sub('{' + 'recovery_id' + '}', CGI.escape(recovery_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'account_password_update'])

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountManagementApi.post_accounts_recovery_recovery_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountManagementApi#post_accounts_recovery_recovery_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_migration(opts = {}) ⇒ UserAccountMigration

Account Creator for migrating users Creates an ‘Account` for an user using the specified info.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_migration (AccountMigration)

    This model has the required information to create an &#x60;Account&#x60;. The &#x60;org_creation_strategy&#x60; field value behavior is: - &#x60;force&#x60;: A &#x60;Company&#x60; will be created with a default name. - &#x60;no&#x60;: The user will have to manually create a Company later. - &#x60;auto&#x60;: The server will decide.

Returns:



95
96
97
98
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 95

def post_migration(opts = {})
  data, _status_code, _headers = post_migration_with_http_info(opts)
  data
end

#post_migration_with_http_info(opts = {}) ⇒ Array<(UserAccountMigration, Integer, Hash)>

Account Creator for migrating users Creates an &#x60;Account&#x60; for an user using the specified info.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_migration (AccountMigration)

    This model has the required information to create an &#x60;Account&#x60;. The &#x60;org_creation_strategy&#x60; field value behavior is: - &#x60;force&#x60;: A &#x60;Company&#x60; will be created with a default name. - &#x60;no&#x60;: The user will have to manually create a Company later. - &#x60;auto&#x60;: The server will decide.

Returns:

  • (Array<(UserAccountMigration, Integer, Hash)>)

    UserAccountMigration data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 105

def post_migration_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountManagementApi.post_migration ...'
  end
  # resource path
  local_var_path = '/v2/accounts/migration'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'account_migration'])

  # return_type
  return_type = opts[:debug_return_type] || 'UserAccountMigration'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountManagementApi.post_migration",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountManagementApi#post_migration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_signup(opts = {}) ⇒ UserAccount

Account Creator Creates an ‘Account` for an user using the specified info.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_signup (AccountSignup)

    This model has the required information to create an &#x60;Account&#x60;. The &#x60;org_creation_strategy&#x60; field value behavior is: - &#x60;force&#x60;: A &#x60;Company&#x60; will be created with a default name. - &#x60;no&#x60;: The user will have to manually create a Company later. - &#x60;auto&#x60;: The server will decide.

Returns:



159
160
161
162
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 159

def (opts = {})
  data, _status_code, _headers = (opts)
  data
end

#post_signup_with_http_info(opts = {}) ⇒ Array<(UserAccount, Integer, Hash)>

Account Creator Creates an &#x60;Account&#x60; for an user using the specified info.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_signup (AccountSignup)

    This model has the required information to create an &#x60;Account&#x60;. The &#x60;org_creation_strategy&#x60; field value behavior is: - &#x60;force&#x60;: A &#x60;Company&#x60; will be created with a default name. - &#x60;no&#x60;: The user will have to manually create a Company later. - &#x60;auto&#x60;: The server will decide.

Returns:

  • (Array<(UserAccount, Integer, Hash)>)

    UserAccount data, response status code and response headers



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 169

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountManagementApi.post_signup ...'
  end
  # resource path
  local_var_path = '/v2/accounts/signup'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'account_signup'])

  # return_type
  return_type = opts[:debug_return_type] || 'UserAccount'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountManagementApi.post_signup",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountManagementApi#post_signup\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#request_account_recovery(opts = {}) ⇒ nil

Account recovery mail sender Sends a link to the account email address that will guide the user to change the account password.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (nil)


223
224
225
226
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 223

def (opts = {})
  (opts)
  nil
end

#request_account_recovery_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Account recovery mail sender Sends a link to the account email address that will guide the user to change the account password.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 233

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountManagementApi.request_account_recovery ...'
  end
  # resource path
  local_var_path = '/v2/accounts/recovery'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'account_recovery'])

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountManagementApi.request_account_recovery",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountManagementApi#request_account_recovery\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#reset_account_password(opts = {}) ⇒ nil

Reset password for account

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (nil)


284
285
286
287
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 284

def (opts = {})
  (opts)
  nil
end

#reset_account_password_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Reset password for account

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 293

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountManagementApi.reset_account_password ...'
  end
  # resource path
  local_var_path = '/v2/accounts/reset-password'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'account_reset_password'])

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountManagementApi.reset_account_password",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountManagementApi#reset_account_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#send_account_invitation(opts = {}) ⇒ nil

Send Account Invitation

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (nil)


344
345
346
347
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 344

def (opts = {})
  (opts)
  nil
end

#send_account_invitation_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Send Account Invitation

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/cropwise-platform-sdk/api/account_management_api.rb', line 353

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountManagementApi.send_account_invitation ...'
  end
  # resource path
  local_var_path = '/v2/accounts/invitation'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'account_invitation'])

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountManagementApi.send_account_invitation",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountManagementApi#send_account_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end