Class: CropwisePlatformSdk::AppApi
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::AppApi
- Defined in:
- lib/cropwise-platform-sdk/api/app_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_developer_app(opts = {}) ⇒ GetDeveloperAppById200Response
Developer App Creator Create a App.
-
#create_developer_app_with_http_info(opts = {}) ⇒ Array<(GetDeveloperAppById200Response, Integer, Hash)>
Developer App Creator Create a App.
-
#delete_app_by_id(app_id, opts = {}) ⇒ nil
Delete the specified App.
-
#delete_app_by_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete the specified App.
-
#delete_app_icon_by_app_id(app_id, opts = {}) ⇒ nil
Remove App Icon Removes the ‘App` main icon.
-
#delete_app_icon_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove App Icon Removes the `App` main icon.
-
#delete_app_image_by_app_id(app_id, opts = {}) ⇒ nil
Remove App Image Removes the ‘App` image.
-
#delete_app_image_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove App Image Removes the `App` image.
-
#get_app_icon_by_app_id(app_id, opts = {}) ⇒ nil
Get App Icon Requests the ‘App` main icon.
-
#get_app_icon_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get App Icon Requests the `App` main icon.
-
#get_app_image_by_app_id(app_id, opts = {}) ⇒ nil
Get App Image Requests the ‘App` main image.
-
#get_app_image_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get App Image Requests the `App` main image.
-
#get_developer_app_by_id(app_id, opts = {}) ⇒ GetDeveloperAppById200Response
Get Developer App By Id Get a App by ID.
-
#get_developer_app_by_id_with_http_info(app_id, opts = {}) ⇒ Array<(GetDeveloperAppById200Response, Integer, Hash)>
Get Developer App By Id Get a App by ID.
-
#get_oauth2_clients_by_app_id(app_id, opts = {}) ⇒ PagedOauthModel
Get All Oauth2 Clients By App Id Get oauth2 client by App ID.
-
#get_oauth2_clients_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(PagedOauthModel, Integer, Hash)>
Get All Oauth2 Clients By App Id Get oauth2 client by App ID.
-
#get_store_app_by_id(app_id, workspace_id, opts = {}) ⇒ BasicApp
Get App By Id in Store Get App By Id in Store.
-
#get_store_app_by_id_with_http_info(app_id, workspace_id, opts = {}) ⇒ Array<(BasicApp, Integer, Hash)>
Get App By Id in Store Get App By Id in Store.
-
#get_store_apps(opts = {}) ⇒ PagedBasicApp
List Apps in Store List Apps in Store.
-
#get_store_apps_per_workspace(opts = {}) ⇒ PagedStorePerWorkspace
List Apps in Store per workspace List Apps in Store per workspace, for all the workspaces with at least one organization.
-
#get_store_apps_per_workspace_with_http_info(opts = {}) ⇒ Array<(PagedStorePerWorkspace, Integer, Hash)>
List Apps in Store per workspace List Apps in Store per workspace, for all the workspaces with at least one organization.
-
#get_store_apps_with_http_info(opts = {}) ⇒ Array<(PagedBasicApp, Integer, Hash)>
List Apps in Store List Apps in Store.
-
#get_v2_apps(opts = {}) ⇒ PagedUserApp
List Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#get_v2_apps_app_id_authorities(app_id, opts = {}) ⇒ PagedAuthority
Get authorities by application List of authorities by ‘App`.
-
#get_v2_apps_app_id_authorities_with_http_info(app_id, opts = {}) ⇒ Array<(PagedAuthority, Integer, Hash)>
Get authorities by application List of authorities by `App`.
-
#get_v2_apps_app_id_info(app_id, opts = {}) ⇒ BasicApp
Get Basic App Info by Id.
-
#get_v2_apps_app_id_info_with_http_info(app_id, opts = {}) ⇒ Array<(BasicApp, Integer, Hash)>
Get Basic App Info by Id.
-
#get_v2_apps_authorities(opts = {}) ⇒ PagedAuthority
Get authorities by application List of authorities by ‘App` of the user logged.
-
#get_v2_apps_authorities_with_http_info(opts = {}) ⇒ Array<(PagedAuthority, Integer, Hash)>
Get authorities by application List of authorities by `App` of the user logged.
-
#get_v2_apps_projects(opts = {}) ⇒ PagedDeveloperApp
List Developer Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#get_v2_apps_projects_with_http_info(opts = {}) ⇒ Array<(PagedDeveloperApp, Integer, Hash)>
List Developer Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#get_v2_apps_with_http_info(opts = {}) ⇒ Array<(PagedUserApp, Integer, Hash)>
List Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#get_v2_orgs_org_id_apps(org_id, parent_region_id, opts = {}) ⇒ PagedDeveloperApp
Installed apps for Org Get All Apps.
-
#get_v2_orgs_org_id_apps_with_http_info(org_id, parent_region_id, opts = {}) ⇒ Array<(PagedDeveloperApp, Integer, Hash)>
Installed apps for Org Get All Apps.
-
#initialize(api_client = ApiClient.default) ⇒ AppApi
constructor
A new instance of AppApi.
-
#post_app_icon(app_id, opts = {}) ⇒ PostAccountPhoto200Response
Upload App Icon Uploads App main icon.
-
#post_app_icon_with_http_info(app_id, opts = {}) ⇒ Array<(PostAccountPhoto200Response, Integer, Hash)>
Upload App Icon Uploads App main icon.
-
#post_app_image(app_id, opts = {}) ⇒ PostAccountPhoto200Response
Upload App Image Uploads App image.
-
#post_app_image_with_http_info(app_id, opts = {}) ⇒ Array<(PostAccountPhoto200Response, Integer, Hash)>
Upload App Image Uploads App image.
-
#post_v2_apps_app_id_install(app_id, opts = {}) ⇒ nil
App installer ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#post_v2_apps_app_id_install_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
App installer ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#post_v2_apps_enroll(opts = {}) ⇒ DeveloperApp
Enroll an App ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#post_v2_apps_enroll_with_http_info(opts = {}) ⇒ Array<(DeveloperApp, Integer, Hash)>
Enroll an App ** NOTE: ** This is **NOT IMPLEMENTED** yet.
-
#update_developer_app(app_id, opts = {}) ⇒ GetDeveloperAppById200Response
Update Developer App Update a App.
-
#update_developer_app_with_http_info(app_id, opts = {}) ⇒ Array<(GetDeveloperAppById200Response, Integer, Hash)>
Update Developer App Update a App.
-
#v2_apps_app_id_campaigns_get(app_id, opts = {}) ⇒ PageableCampaigns
Get Campaigns by app.
-
#v2_apps_app_id_campaigns_get_with_http_info(app_id, opts = {}) ⇒ Array<(PageableCampaigns, Integer, Hash)>
Get Campaigns by app.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_developer_app(opts = {}) ⇒ GetDeveloperAppById200Response
Developer App Creator Create a App.
27 28 29 30 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 27 def create_developer_app(opts = {}) data, _status_code, _headers = create_developer_app_with_http_info(opts) data end |
#create_developer_app_with_http_info(opts = {}) ⇒ Array<(GetDeveloperAppById200Response, Integer, Hash)>
Developer App Creator Create a App.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 37 def create_developer_app_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.create_developer_app ...' end # resource path local_var_path = '/v2/apps' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'developer_app']) # return_type return_type = opts[:debug_return_type] || 'GetDeveloperAppById200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.create_developer_app", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#create_developer_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_app_by_id(app_id, opts = {}) ⇒ nil
Delete the specified App.
91 92 93 94 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 91 def delete_app_by_id(app_id, opts = {}) delete_app_by_id_with_http_info(app_id, opts) nil end |
#delete_app_by_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete the specified App.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 101 def delete_app_by_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.delete_app_by_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.delete_app_by_id" end # resource path local_var_path = '/v2/apps/{app_id}'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.delete_app_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#delete_app_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_app_icon_by_app_id(app_id, opts = {}) ⇒ nil
Remove App Icon Removes the ‘App` main icon.
152 153 154 155 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 152 def delete_app_icon_by_app_id(app_id, opts = {}) delete_app_icon_by_app_id_with_http_info(app_id, opts) nil end |
#delete_app_icon_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove App Icon Removes the `App` main icon.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 162 def delete_app_icon_by_app_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.delete_app_icon_by_app_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.delete_app_icon_by_app_id" end # resource path local_var_path = '/v2/apps/{app_id}/icon'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.delete_app_icon_by_app_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#delete_app_icon_by_app_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_app_image_by_app_id(app_id, opts = {}) ⇒ nil
Remove App Image Removes the ‘App` image.
215 216 217 218 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 215 def delete_app_image_by_app_id(app_id, opts = {}) delete_app_image_by_app_id_with_http_info(app_id, opts) nil end |
#delete_app_image_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove App Image Removes the `App` image.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 225 def delete_app_image_by_app_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.delete_app_image_by_app_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.delete_app_image_by_app_id" end # resource path local_var_path = '/v2/apps/{app_id}/image'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.delete_app_image_by_app_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#delete_app_image_by_app_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_app_icon_by_app_id(app_id, opts = {}) ⇒ nil
Get App Icon Requests the ‘App` main icon.
278 279 280 281 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 278 def get_app_icon_by_app_id(app_id, opts = {}) get_app_icon_by_app_id_with_http_info(app_id, opts) nil end |
#get_app_icon_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get App Icon Requests the `App` main icon.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 288 def get_app_icon_by_app_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_app_icon_by_app_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_app_icon_by_app_id" end # resource path local_var_path = '/v2/apps/{app_id}/icon'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_app_icon_by_app_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_app_icon_by_app_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_app_image_by_app_id(app_id, opts = {}) ⇒ nil
Get App Image Requests the ‘App` main image.
341 342 343 344 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 341 def get_app_image_by_app_id(app_id, opts = {}) get_app_image_by_app_id_with_http_info(app_id, opts) nil end |
#get_app_image_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get App Image Requests the `App` main image.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 351 def get_app_image_by_app_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_app_image_by_app_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_app_image_by_app_id" end # resource path local_var_path = '/v2/apps/{app_id}/image'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_app_image_by_app_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_app_image_by_app_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_developer_app_by_id(app_id, opts = {}) ⇒ GetDeveloperAppById200Response
Get Developer App By Id Get a App by ID.
404 405 406 407 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 404 def get_developer_app_by_id(app_id, opts = {}) data, _status_code, _headers = get_developer_app_by_id_with_http_info(app_id, opts) data end |
#get_developer_app_by_id_with_http_info(app_id, opts = {}) ⇒ Array<(GetDeveloperAppById200Response, Integer, Hash)>
Get Developer App By Id Get a App by ID.
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 414 def get_developer_app_by_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_developer_app_by_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_developer_app_by_id" end # resource path local_var_path = '/v2/apps/{app_id}'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetDeveloperAppById200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_developer_app_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_developer_app_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_oauth2_clients_by_app_id(app_id, opts = {}) ⇒ PagedOauthModel
Get All Oauth2 Clients By App Id Get oauth2 client by App ID.
467 468 469 470 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 467 def get_oauth2_clients_by_app_id(app_id, opts = {}) data, _status_code, _headers = get_oauth2_clients_by_app_id_with_http_info(app_id, opts) data end |
#get_oauth2_clients_by_app_id_with_http_info(app_id, opts = {}) ⇒ Array<(PagedOauthModel, Integer, Hash)>
Get All Oauth2 Clients By App Id Get oauth2 client by App ID.
477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 477 def get_oauth2_clients_by_app_id_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_oauth2_clients_by_app_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_oauth2_clients_by_app_id" end # resource path local_var_path = '/v2/apps/{app_id}/oauth2-clients'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedOauthModel' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_oauth2_clients_by_app_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_oauth2_clients_by_app_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_store_app_by_id(app_id, workspace_id, opts = {}) ⇒ BasicApp
Get App By Id in Store Get App By Id in Store
532 533 534 535 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 532 def get_store_app_by_id(app_id, workspace_id, opts = {}) data, _status_code, _headers = get_store_app_by_id_with_http_info(app_id, workspace_id, opts) data end |
#get_store_app_by_id_with_http_info(app_id, workspace_id, opts = {}) ⇒ Array<(BasicApp, Integer, Hash)>
Get App By Id in Store Get App By Id in Store
544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 544 def get_store_app_by_id_with_http_info(app_id, workspace_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_store_app_by_id ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_store_app_by_id" end # verify the required parameter 'workspace_id' is set if @api_client.config.client_side_validation && workspace_id.nil? fail ArgumentError, "Missing the required parameter 'workspace_id' when calling AppApi.get_store_app_by_id" end # resource path local_var_path = '/v2/store/apps/{app_id}'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'workspace_id'] = workspace_id query_params[:'include_expired_contracts'] = opts[:'include_expired_contracts'] if !opts[:'include_expired_contracts'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BasicApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_store_app_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_store_app_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_store_apps(opts = {}) ⇒ PagedBasicApp
List Apps in Store List Apps in Store
606 607 608 609 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 606 def get_store_apps(opts = {}) data, _status_code, _headers = get_store_apps_with_http_info(opts) data end |
#get_store_apps_per_workspace(opts = {}) ⇒ PagedStorePerWorkspace
List Apps in Store per workspace List Apps in Store per workspace, for all the workspaces with at least one organization.
676 677 678 679 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 676 def get_store_apps_per_workspace(opts = {}) data, _status_code, _headers = get_store_apps_per_workspace_with_http_info(opts) data end |
#get_store_apps_per_workspace_with_http_info(opts = {}) ⇒ Array<(PagedStorePerWorkspace, Integer, Hash)>
List Apps in Store per workspace List Apps in Store per workspace, for all the workspaces with at least one organization.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 690 def get_store_apps_per_workspace_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_store_apps_per_workspace ...' end # resource path local_var_path = '/v2/store/workspaces/apps' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'filter_by_language'] = opts[:'filter_by_language'] if !opts[:'filter_by_language'].nil? query_params[:'include_default_workspace'] = opts[:'include_default_workspace'] if !opts[:'include_default_workspace'].nil? query_params[:'include_unpublished'] = opts[:'include_unpublished'] if !opts[:'include_unpublished'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedStorePerWorkspace' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_store_apps_per_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_store_apps_per_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_store_apps_with_http_info(opts = {}) ⇒ Array<(PagedBasicApp, Integer, Hash)>
List Apps in Store List Apps in Store
619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 619 def get_store_apps_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_store_apps ...' end # resource path local_var_path = '/v2/store/apps' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'workspace_id'] = opts[:'workspace_id'] if !opts[:'workspace_id'].nil? query_params[:'filter_by_language'] = opts[:'filter_by_language'] if !opts[:'filter_by_language'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedBasicApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_store_apps", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_store_apps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_v2_apps(opts = {}) ⇒ PagedUserApp
List Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress. List apps from market place
743 744 745 746 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 743 def get_v2_apps(opts = {}) data, _status_code, _headers = get_v2_apps_with_http_info(opts) data end |
#get_v2_apps_app_id_authorities(app_id, opts = {}) ⇒ PagedAuthority
Get authorities by application List of authorities by ‘App`
801 802 803 804 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 801 def (app_id, opts = {}) data, _status_code, _headers = (app_id, opts) data end |
#get_v2_apps_app_id_authorities_with_http_info(app_id, opts = {}) ⇒ Array<(PagedAuthority, Integer, Hash)>
Get authorities by application List of authorities by `App`
811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 811 def (app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_v2_apps_app_id_authorities ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_v2_apps_app_id_authorities" end # resource path local_var_path = '/v2/apps/{app_id}/authorities'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedAuthority' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_v2_apps_app_id_authorities", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_v2_apps_app_id_authorities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_v2_apps_app_id_info(app_id, opts = {}) ⇒ BasicApp
Get Basic App Info by Id
864 865 866 867 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 864 def get_v2_apps_app_id_info(app_id, opts = {}) data, _status_code, _headers = get_v2_apps_app_id_info_with_http_info(app_id, opts) data end |
#get_v2_apps_app_id_info_with_http_info(app_id, opts = {}) ⇒ Array<(BasicApp, Integer, Hash)>
Get Basic App Info by Id
874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 874 def get_v2_apps_app_id_info_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_v2_apps_app_id_info ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.get_v2_apps_app_id_info" end # resource path local_var_path = '/v2/apps/{app_id}/info'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BasicApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_v2_apps_app_id_info", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_v2_apps_app_id_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_v2_apps_authorities(opts = {}) ⇒ PagedAuthority
Get authorities by application List of authorities by ‘App` of the user logged
927 928 929 930 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 927 def (opts = {}) data, _status_code, _headers = (opts) data end |
#get_v2_apps_authorities_with_http_info(opts = {}) ⇒ Array<(PagedAuthority, Integer, Hash)>
Get authorities by application List of authorities by `App` of the user logged
936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 936 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_v2_apps_authorities ...' end # resource path local_var_path = '/v2/apps/authorities' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedAuthority' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_v2_apps_authorities", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_v2_apps_authorities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_v2_apps_projects(opts = {}) ⇒ PagedDeveloperApp
List Developer Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress.
984 985 986 987 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 984 def get_v2_apps_projects(opts = {}) data, _status_code, _headers = get_v2_apps_projects_with_http_info(opts) data end |
#get_v2_apps_projects_with_http_info(opts = {}) ⇒ Array<(PagedDeveloperApp, Integer, Hash)>
List Developer Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress.
993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 993 def get_v2_apps_projects_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_v2_apps_projects ...' end # resource path local_var_path = '/v2/apps/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedDeveloperApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_v2_apps_projects", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_v2_apps_projects\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_v2_apps_with_http_info(opts = {}) ⇒ Array<(PagedUserApp, Integer, Hash)>
List Apps ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress. List apps from market place
752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 752 def get_v2_apps_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_v2_apps ...' end # resource path local_var_path = '/v2/apps' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedUserApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_v2_apps", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_v2_apps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_v2_orgs_org_id_apps(org_id, parent_region_id, opts = {}) ⇒ PagedDeveloperApp
Installed apps for Org Get All Apps
1046 1047 1048 1049 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1046 def get_v2_orgs_org_id_apps(org_id, parent_region_id, opts = {}) data, _status_code, _headers = get_v2_orgs_org_id_apps_with_http_info(org_id, parent_region_id, opts) data end |
#get_v2_orgs_org_id_apps_with_http_info(org_id, parent_region_id, opts = {}) ⇒ Array<(PagedDeveloperApp, Integer, Hash)>
Installed apps for Org Get All Apps
1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1060 def get_v2_orgs_org_id_apps_with_http_info(org_id, parent_region_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.get_v2_orgs_org_id_apps ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling AppApi.get_v2_orgs_org_id_apps" end # verify the required parameter 'parent_region_id' is set if @api_client.config.client_side_validation && parent_region_id.nil? fail ArgumentError, "Missing the required parameter 'parent_region_id' when calling AppApi.get_v2_orgs_org_id_apps" end allowable_values = ["geometry"] if @api_client.config.client_side_validation && opts[:'attributes'] && !opts[:'attributes'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"attributes\", must include one of #{allowable_values}" end # resource path local_var_path = '/v2/orgs/{org_id}/apps'.sub('{' + 'org_id' + '}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'parent_region_id'] = parent_region_id query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'attributes'] = @api_client.build_collection_param(opts[:'attributes'], :csv) if !opts[:'attributes'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedDeveloperApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.get_v2_orgs_org_id_apps", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#get_v2_orgs_org_id_apps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_app_icon(app_id, opts = {}) ⇒ PostAccountPhoto200Response
Upload App Icon Uploads App main icon.
1126 1127 1128 1129 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1126 def post_app_icon(app_id, opts = {}) data, _status_code, _headers = post_app_icon_with_http_info(app_id, opts) data end |
#post_app_icon_with_http_info(app_id, opts = {}) ⇒ Array<(PostAccountPhoto200Response, Integer, Hash)>
Upload App Icon Uploads App main icon.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1137 def post_app_icon_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.post_app_icon ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.post_app_icon" end # resource path local_var_path = '/v2/apps/{app_id}/icon'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['icon'] = opts[:'icon'] if !opts[:'icon'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PostAccountPhoto200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.post_app_icon", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#post_app_icon\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_app_image(app_id, opts = {}) ⇒ PostAccountPhoto200Response
Upload App Image Uploads App image.
1197 1198 1199 1200 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1197 def post_app_image(app_id, opts = {}) data, _status_code, _headers = post_app_image_with_http_info(app_id, opts) data end |
#post_app_image_with_http_info(app_id, opts = {}) ⇒ Array<(PostAccountPhoto200Response, Integer, Hash)>
Upload App Image Uploads App image.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1208 def post_app_image_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.post_app_image ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.post_app_image" end # resource path local_var_path = '/v2/apps/{app_id}/image'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['image'] = opts[:'image'] if !opts[:'image'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PostAccountPhoto200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.post_app_image", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#post_app_image\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_v2_apps_app_id_install(app_id, opts = {}) ⇒ nil
App installer ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress.
1268 1269 1270 1271 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1268 def post_v2_apps_app_id_install(app_id, opts = {}) post_v2_apps_app_id_install_with_http_info(app_id, opts) nil end |
#post_v2_apps_app_id_install_with_http_info(app_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
App installer ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress.
1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1279 def post_v2_apps_app_id_install_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.post_v2_apps_app_id_install ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.post_v2_apps_app_id_install" end # resource path local_var_path = '/v2/apps/{app_id}/installation'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'app_installation']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.post_v2_apps_app_id_install", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#post_v2_apps_app_id_install\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_v2_apps_enroll(opts = {}) ⇒ DeveloperApp
Enroll an App ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress.
1335 1336 1337 1338 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1335 def post_v2_apps_enroll(opts = {}) data, _status_code, _headers = post_v2_apps_enroll_with_http_info(opts) data end |
#post_v2_apps_enroll_with_http_info(opts = {}) ⇒ Array<(DeveloperApp, Integer, Hash)>
Enroll an App ** NOTE: ** This is **NOT IMPLEMENTED** yet. It is still work in progress.
1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1345 def post_v2_apps_enroll_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.post_v2_apps_enroll ...' end # resource path local_var_path = '/v2/apps/enrollment' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'app_enrollment']) # return_type return_type = opts[:debug_return_type] || 'DeveloperApp' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.post_v2_apps_enroll", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#post_v2_apps_enroll\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_developer_app(app_id, opts = {}) ⇒ GetDeveloperAppById200Response
Update Developer App Update a App.
1400 1401 1402 1403 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1400 def update_developer_app(app_id, opts = {}) data, _status_code, _headers = update_developer_app_with_http_info(app_id, opts) data end |
#update_developer_app_with_http_info(app_id, opts = {}) ⇒ Array<(GetDeveloperAppById200Response, Integer, Hash)>
Update Developer App Update a App.
1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1411 def update_developer_app_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.update_developer_app ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.update_developer_app" end # resource path local_var_path = '/v2/apps/{app_id}'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'developer_app']) # return_type return_type = opts[:debug_return_type] || 'GetDeveloperAppById200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.update_developer_app", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#update_developer_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v2_apps_app_id_campaigns_get(app_id, opts = {}) ⇒ PageableCampaigns
Get Campaigns by app
1470 1471 1472 1473 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1470 def v2_apps_app_id_campaigns_get(app_id, opts = {}) data, _status_code, _headers = v2_apps_app_id_campaigns_get_with_http_info(app_id, opts) data end |
#v2_apps_app_id_campaigns_get_with_http_info(app_id, opts = {}) ⇒ Array<(PageableCampaigns, Integer, Hash)>
Get Campaigns by app
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 |
# File 'lib/cropwise-platform-sdk/api/app_api.rb', line 1481 def v2_apps_app_id_campaigns_get_with_http_info(app_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppApi.v2_apps_app_id_campaigns_get ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling AppApi.v2_apps_app_id_campaigns_get" end # resource path local_var_path = '/v2/apps/{app_id}/campaigns'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'last_key'] = opts[:'last_key'] if !opts[:'last_key'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PageableCampaigns' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AppApi.v2_apps_app_id_campaigns_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppApi#v2_apps_app_id_campaigns_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |