Class: CropwisePlatformSdk::BasicEquipmentCatalogue

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BasicEquipmentCatalogue

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::BasicEquipmentCatalogue` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::BasicEquipmentCatalogue`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'org_id')
    self.org_id = attributes[:'org_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'property_ids')
    if (value = attributes[:'property_ids']).is_a?(Array)
      self.property_ids = value
    end
  end

  if attributes.key?(:'json_extended_attributes')
    self.json_extended_attributes = attributes[:'json_extended_attributes']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'licensing_number')
    self.licensing_number = attributes[:'licensing_number']
  end

  if attributes.key?(:'unit_id')
    self.unit_id = attributes[:'unit_id']
  end

  if attributes.key?(:'serial_number')
    self.serial_number = attributes[:'serial_number']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'current_status')
    self.current_status = attributes[:'current_status']
  end

  if attributes.key?(:'current_status_date')
    self.current_status_date = attributes[:'current_status_date']
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'year')
    self.year = attributes[:'year']
  end

  if attributes.key?(:'manufacturer')
    self.manufacturer = attributes[:'manufacturer']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#current_statusObject

Returns the value of attribute current_status.



37
38
39
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 37

def current_status
  @current_status
end

#current_status_dateObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



40
41
42
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 40

def current_status_date
  @current_status_date
end

#json_extended_attributesObject

Returns the value of attribute json_extended_attributes.



25
26
27
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 25

def json_extended_attributes
  @json_extended_attributes
end

#labelObject

Returns the value of attribute label.



27
28
29
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 27

def label
  @label
end

#licensing_numberObject

Returns the value of attribute licensing_number.



29
30
31
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 29

def licensing_number
  @licensing_number
end

#manufacturerObject

Returns the value of attribute manufacturer.



46
47
48
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 46

def manufacturer
  @manufacturer
end

#modelObject

Returns the value of attribute model.



42
43
44
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 42

def model
  @model
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 21

def name
  @name
end

#notesObject

Returns the value of attribute notes.



35
36
37
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 35

def notes
  @notes
end

#org_idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



19
20
21
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 19

def org_id
  @org_id
end

#property_idsObject

Returns the value of attribute property_ids.



23
24
25
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 23

def property_ids
  @property_ids
end

#serial_numberObject

Returns the value of attribute serial_number.



33
34
35
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 33

def serial_number
  @serial_number
end

#typeObject

Returns the value of attribute type.



48
49
50
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 48

def type
  @type
end

#unit_idObject

Returns the value of attribute unit_id.



31
32
33
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 31

def unit_id
  @unit_id
end

#yearObject

Returns the value of attribute year.



44
45
46
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 44

def year
  @year
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 94

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 73

def self.attribute_map
  {
    :'org_id' => :'org_id',
    :'name' => :'name',
    :'property_ids' => :'property_ids',
    :'json_extended_attributes' => :'json_extended_attributes',
    :'label' => :'label',
    :'licensing_number' => :'licensing_number',
    :'unit_id' => :'unit_id',
    :'serial_number' => :'serial_number',
    :'notes' => :'notes',
    :'current_status' => :'current_status',
    :'current_status_date' => :'current_status_date',
    :'model' => :'model',
    :'year' => :'year',
    :'manufacturer' => :'manufacturer',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



297
298
299
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 297

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



126
127
128
129
130
131
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 126

def self.openapi_all_of
  [
  :'BasicEquipment',
  :'BasicEquipmentCatalogueAllOf'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 99

def self.openapi_types
  {
    :'org_id' => :'String',
    :'name' => :'String',
    :'property_ids' => :'Array<String>',
    :'json_extended_attributes' => :'BasicExtendedAttribute',
    :'label' => :'String',
    :'licensing_number' => :'String',
    :'unit_id' => :'String',
    :'serial_number' => :'String',
    :'notes' => :'String',
    :'current_status' => :'String',
    :'current_status_date' => :'Time',
    :'model' => :'String',
    :'year' => :'Integer',
    :'manufacturer' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      org_id == o.org_id &&
      name == o.name &&
      property_ids == o.property_ids &&
      json_extended_attributes == o.json_extended_attributes &&
      label == o.label &&
      licensing_number == o.licensing_number &&
      unit_id == o.unit_id &&
      serial_number == o.serial_number &&
      notes == o.notes &&
      current_status == o.current_status &&
      current_status_date == o.current_status_date &&
      model == o.model &&
      year == o.year &&
      manufacturer == o.manufacturer &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 328

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CropwisePlatformSdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 399

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 304

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


284
285
286
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 284

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



290
291
292
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 290

def hash
  [org_id, name, property_ids, json_extended_attributes, label, licensing_number, unit_id, serial_number, notes, current_status, current_status_date, model, year, manufacturer, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 213

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



375
376
377
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 375

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 381

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



369
370
371
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 369

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
228
# File 'lib/cropwise-platform-sdk/models/basic_equipment_catalogue.rb', line 220

def valid?
  label_validator = EnumAttributeValidator.new('String', ["EARTH_MOVING", "FORAGE_AND_HAY", "HARVESTING", "PLANTER", "SPRAYER", "TILLAGE", "TRACTOR", "TRAILER", "TRUCK", "GENERICAL_VEHICLE", "IRRIGATION", "MANURE", "MISC", "FERTILIZER", "SHOP"])
  return false unless label_validator.valid?(@label)
  current_status_validator = EnumAttributeValidator.new('String', ["OWNER", "CONTRACTED", "LEASED", "SOLD", "JUNKED", "CONTRACT_TERMINATED", "LEASE_TERMINATED"])
  return false unless current_status_validator.valid?(@current_status)
  type_validator = EnumAttributeValidator.new('String', ["IMPLEMENT", "VEHICLE"])
  return false unless type_validator.valid?(@type)
  true
end