Class: CropwisePlatformSdk::EditableProperty
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::EditableProperty
- Defined in:
- lib/cropwise-platform-sdk/models/editable_property.rb
Overview
Basic info of a ‘Property` to be edited
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#fields_updated_at ⇒ Object
Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21.
-
#json_extended_attributes ⇒ Object
Returns the value of attribute json_extended_attributes.
-
#name ⇒ Object
Returns the value of attribute name.
-
#org_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#place_id ⇒ Object
Returns the value of attribute place_id.
-
#reference_point ⇒ Object
Returns the value of attribute reference_point.
-
#regulatory_zone ⇒ Object
Returns the value of attribute regulatory_zone.
-
#root_region_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#state ⇒ Object
Returns the value of attribute state.
-
#time_zone ⇒ Object
Returns the value of attribute time_zone.
-
#zip_code ⇒ Object
Returns the value of attribute zip_code.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EditableProperty
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EditableProperty
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 133 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::EditableProperty` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::EditableProperty`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'org_id') self.org_id = attributes[:'org_id'] end if attributes.key?(:'root_region_id') self.root_region_id = attributes[:'root_region_id'] end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'zip_code') self.zip_code = attributes[:'zip_code'] end if attributes.key?(:'place_id') self.place_id = attributes[:'place_id'] end if attributes.key?(:'fields_updated_at') self.fields_updated_at = attributes[:'fields_updated_at'] end if attributes.key?(:'reference_point') self.reference_point = attributes[:'reference_point'] end if attributes.key?(:'regulatory_zone') self.regulatory_zone = attributes[:'regulatory_zone'] end if attributes.key?(:'json_extended_attributes') self.json_extended_attributes = attributes[:'json_extended_attributes'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
35 36 37 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 35 def address @address end |
#city ⇒ Object
Returns the value of attribute city.
33 34 35 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 33 def city @city end |
#country ⇒ Object
Returns the value of attribute country.
29 30 31 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 29 def country @country end |
#fields_updated_at ⇒ Object
Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21
42 43 44 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 42 def fields_updated_at @fields_updated_at end |
#json_extended_attributes ⇒ Object
Returns the value of attribute json_extended_attributes.
48 49 50 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 48 def json_extended_attributes @json_extended_attributes end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 19 def name @name end |
#org_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 22 def org_id @org_id end |
#place_id ⇒ Object
Returns the value of attribute place_id.
39 40 41 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 39 def place_id @place_id end |
#reference_point ⇒ Object
Returns the value of attribute reference_point.
44 45 46 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 44 def reference_point @reference_point end |
#regulatory_zone ⇒ Object
Returns the value of attribute regulatory_zone.
46 47 48 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 46 def regulatory_zone @regulatory_zone end |
#root_region_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
25 26 27 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 25 def root_region_id @root_region_id end |
#state ⇒ Object
Returns the value of attribute state.
31 32 33 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 31 def state @state end |
#time_zone ⇒ Object
Returns the value of attribute time_zone.
27 28 29 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 27 def time_zone @time_zone end |
#zip_code ⇒ Object
Returns the value of attribute zip_code.
37 38 39 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 37 def zip_code @zip_code end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 93 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 73 def self.attribute_map { :'name' => :'name', :'org_id' => :'org_id', :'root_region_id' => :'root_region_id', :'time_zone' => :'time_zone', :'country' => :'country', :'state' => :'state', :'city' => :'city', :'address' => :'address', :'zip_code' => :'zip_code', :'place_id' => :'place_id', :'fields_updated_at' => :'fields_updated_at', :'reference_point' => :'reference_point', :'regulatory_zone' => :'regulatory_zone', :'json_extended_attributes' => :'json_extended_attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 272 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
124 125 126 127 128 129 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 124 def self.openapi_all_of [ :'EditablePropertyAllOf', :'NamedModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 98 def self.openapi_types { :'name' => :'String', :'org_id' => :'String', :'root_region_id' => :'String', :'time_zone' => :'TimeZone', :'country' => :'String', :'state' => :'String', :'city' => :'String', :'address' => :'String', :'zip_code' => :'String', :'place_id' => :'String', :'fields_updated_at' => :'Time', :'reference_point' => :'Point', :'regulatory_zone' => :'ISO3166Alpha2Code', :'json_extended_attributes' => :'BasicExtendedAttribute' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && org_id == o.org_id && root_region_id == o.root_region_id && time_zone == o.time_zone && country == o.country && state == o.state && city == o.city && address == o.address && zip_code == o.zip_code && place_id == o.place_id && fields_updated_at == o.fields_updated_at && reference_point == o.reference_point && regulatory_zone == o.regulatory_zone && json_extended_attributes == o.json_extended_attributes end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 303 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 374 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 279 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 265 def hash [name, org_id, root_region_id, time_zone, country, state, city, address, zip_code, place_id, fields_updated_at, reference_point, regulatory_zone, json_extended_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 205 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @org_id.nil? invalid_properties.push('invalid value for "org_id", org_id cannot be nil.') end if @time_zone.nil? invalid_properties.push('invalid value for "time_zone", time_zone cannot be nil.') end if @reference_point.nil? invalid_properties.push('invalid value for "reference_point", reference_point cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
350 351 352 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 350 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
344 345 346 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 344 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 231 232 233 234 |
# File 'lib/cropwise-platform-sdk/models/editable_property.rb', line 228 def valid? return false if @name.nil? return false if @org_id.nil? return false if @time_zone.nil? return false if @reference_point.nil? true end |