Class: CropwisePlatformSdk::EmailTemplateApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/api/email_template_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EmailTemplateApi

Returns a new instance of EmailTemplateApi.



19
20
21
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_email_template_by_id(template_id, opts = {}) ⇒ nil

Delete an EmailTemplate Delete the specified ‘EmailTemplate`.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


27
28
29
30
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 27

def delete_email_template_by_id(template_id, opts = {})
  delete_email_template_by_id_with_http_info(template_id, opts)
  nil
end

#delete_email_template_by_id_with_http_info(template_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete an EmailTemplate Delete the specified &#x60;EmailTemplate&#x60;.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 37

def delete_email_template_by_id_with_http_info(template_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.delete_email_template_by_id ...'
  end
  # verify the required parameter 'template_id' is set
  if @api_client.config.client_side_validation && template_id.nil?
    fail ArgumentError, "Missing the required parameter 'template_id' when calling EmailTemplateApi.delete_email_template_by_id"
  end
  # resource path
  local_var_path = '/v2/email/templates/{template_id}'.sub('{' + 'template_id' + '}', CGI.escape(template_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.delete_email_template_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#delete_email_template_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#edit_email_template_by_template_id(template_id, opts = {}) ⇒ EmailTemplate

Edit EmailTemplate Edits an existing ‘EmailTemplate` with the specified id.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



89
90
91
92
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 89

def edit_email_template_by_template_id(template_id, opts = {})
  data, _status_code, _headers = edit_email_template_by_template_id_with_http_info(template_id, opts)
  data
end

#edit_email_template_by_template_id_with_http_info(template_id, opts = {}) ⇒ Array<(EmailTemplate, Integer, Hash)>

Edit EmailTemplate Edits an existing &#x60;EmailTemplate&#x60; with the specified id.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(EmailTemplate, Integer, Hash)>)

    EmailTemplate data, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 100

def edit_email_template_by_template_id_with_http_info(template_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.edit_email_template_by_template_id ...'
  end
  # verify the required parameter 'template_id' is set
  if @api_client.config.client_side_validation && template_id.nil?
    fail ArgumentError, "Missing the required parameter 'template_id' when calling EmailTemplateApi.edit_email_template_by_template_id"
  end
  # resource path
  local_var_path = '/v2/email/templates/{template_id}'.sub('{' + 'template_id' + '}', CGI.escape(template_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'email_template'])

  # return_type
  return_type = opts[:debug_return_type] || 'EmailTemplate'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.edit_email_template_by_template_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#edit_email_template_by_template_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_template_by_id(template_id, opts = {}) ⇒ EmailTemplate

EmailTemplate Details Gets the specified EmailTemplate details.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



158
159
160
161
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 158

def get_template_by_id(template_id, opts = {})
  data, _status_code, _headers = get_template_by_id_with_http_info(template_id, opts)
  data
end

#get_template_by_id_with_http_info(template_id, opts = {}) ⇒ Array<(EmailTemplate, Integer, Hash)>

EmailTemplate Details Gets the specified EmailTemplate details.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(EmailTemplate, Integer, Hash)>)

    EmailTemplate data, response status code and response headers



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 168

def get_template_by_id_with_http_info(template_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.get_template_by_id ...'
  end
  # verify the required parameter 'template_id' is set
  if @api_client.config.client_side_validation && template_id.nil?
    fail ArgumentError, "Missing the required parameter 'template_id' when calling EmailTemplateApi.get_template_by_id"
  end
  # resource path
  local_var_path = '/v2/email/templates/{template_id}'.sub('{' + 'template_id' + '}', CGI.escape(template_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EmailTemplate'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.get_template_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#get_template_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_v2_email_template(opts = {}) ⇒ EmailTemplate

EmailTemplate Create EmailTemplate

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



221
222
223
224
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 221

def post_v2_email_template(opts = {})
  data, _status_code, _headers = post_v2_email_template_with_http_info(opts)
  data
end

#post_v2_email_template_with_http_info(opts = {}) ⇒ Array<(EmailTemplate, Integer, Hash)>

EmailTemplate Create EmailTemplate

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(EmailTemplate, Integer, Hash)>)

    EmailTemplate data, response status code and response headers



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 231

def post_v2_email_template_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.post_v2_email_template ...'
  end
  # resource path
  local_var_path = '/v2/email/templates'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'email_template'])

  # return_type
  return_type = opts[:debug_return_type] || 'EmailTemplate'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.post_v2_email_template",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#post_v2_email_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_email_templates_attachment_delete(key, opts = {}) ⇒ nil

Remove attachment Removes the attachment.

Parameters:

  • key (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


285
286
287
288
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 285

def v2_email_templates_attachment_delete(key, opts = {})
  v2_email_templates_attachment_delete_with_http_info(key, opts)
  nil
end

#v2_email_templates_attachment_delete_with_http_info(key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Remove attachment Removes the attachment.

Parameters:

  • key (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 295

def v2_email_templates_attachment_delete_with_http_info(key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.v2_email_templates_attachment_delete ...'
  end
  # verify the required parameter 'key' is set
  if @api_client.config.client_side_validation && key.nil?
    fail ArgumentError, "Missing the required parameter 'key' when calling EmailTemplateApi.v2_email_templates_attachment_delete"
  end
  # resource path
  local_var_path = '/v2/email/templates/attachment'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'key'] = key

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.v2_email_templates_attachment_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#v2_email_templates_attachment_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_email_templates_attachment_post(opts = {}) ⇒ nil

Upload attachment Uploads attachment to be used in custom template.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :file (File)

Returns:

  • (nil)


347
348
349
350
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 347

def v2_email_templates_attachment_post(opts = {})
  v2_email_templates_attachment_post_with_http_info(opts)
  nil
end

#v2_email_templates_attachment_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Upload attachment Uploads attachment to be used in custom template.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :file (File)

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 357

def v2_email_templates_attachment_post_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.v2_email_templates_attachment_post ...'
  end
  # resource path
  local_var_path = '/v2/email/templates/attachment'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['file'] = opts[:'file'] if !opts[:'file'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.v2_email_templates_attachment_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#v2_email_templates_attachment_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_email_templates_image_delete(key, opts = {}) ⇒ nil

Remove image Removes the image.

Parameters:

  • key (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


412
413
414
415
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 412

def v2_email_templates_image_delete(key, opts = {})
  v2_email_templates_image_delete_with_http_info(key, opts)
  nil
end

#v2_email_templates_image_delete_with_http_info(key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Remove image Removes the image.

Parameters:

  • key (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 422

def v2_email_templates_image_delete_with_http_info(key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.v2_email_templates_image_delete ...'
  end
  # verify the required parameter 'key' is set
  if @api_client.config.client_side_validation && key.nil?
    fail ArgumentError, "Missing the required parameter 'key' when calling EmailTemplateApi.v2_email_templates_image_delete"
  end
  # resource path
  local_var_path = '/v2/email/templates/image'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'key'] = key

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.v2_email_templates_image_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#v2_email_templates_image_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_email_templates_image_post(opts = {}) ⇒ nil

Upload image Uploads image to be used in custom template.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :file (File)

Returns:

  • (nil)


474
475
476
477
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 474

def v2_email_templates_image_post(opts = {})
  v2_email_templates_image_post_with_http_info(opts)
  nil
end

#v2_email_templates_image_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Upload image Uploads image to be used in custom template.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :file (File)

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 484

def v2_email_templates_image_post_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.v2_email_templates_image_post ...'
  end
  # resource path
  local_var_path = '/v2/email/templates/image'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['file'] = opts[:'file'] if !opts[:'file'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.v2_email_templates_image_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#v2_email_templates_image_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_email_templates_template_id_send_post(template_id, opts = {}) ⇒ nil

send email send email with custom placeholders.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (nil)


540
541
542
543
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 540

def v2_email_templates_template_id_send_post(template_id, opts = {})
  v2_email_templates_template_id_send_post_with_http_info(template_id, opts)
  nil
end

#v2_email_templates_template_id_send_post_with_http_info(template_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

send email send email with custom placeholders.

Parameters:

  • template_id (String)

    Template ID.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/cropwise-platform-sdk/api/email_template_api.rb', line 551

def v2_email_templates_template_id_send_post_with_http_info(template_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EmailTemplateApi.v2_email_templates_template_id_send_post ...'
  end
  # verify the required parameter 'template_id' is set
  if @api_client.config.client_side_validation && template_id.nil?
    fail ArgumentError, "Missing the required parameter 'template_id' when calling EmailTemplateApi.v2_email_templates_template_id_send_post"
  end
  # resource path
  local_var_path = '/v2/email/templates/{template_id}/send'.sub('{' + 'template_id' + '}', CGI.escape(template_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'send_email'])

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"EmailTemplateApi.v2_email_templates_template_id_send_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EmailTemplateApi#v2_email_templates_template_id_send_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end