Class: CropwisePlatformSdk::EquipmentCatalogue
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::EquipmentCatalogue
- Defined in:
- lib/cropwise-platform-sdk/models/equipment_catalogue.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#current_status ⇒ Object
Returns the value of attribute current_status.
-
#current_status_date ⇒ Object
Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21.
-
#id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#json_extended_attributes ⇒ Object
Returns the value of attribute json_extended_attributes.
-
#label ⇒ Object
Returns the value of attribute label.
-
#licensing_number ⇒ Object
Returns the value of attribute licensing_number.
-
#manufacturer ⇒ Object
Returns the value of attribute manufacturer.
-
#model ⇒ Object
Returns the value of attribute model.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#org_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#property_ids ⇒ Object
Returns the value of attribute property_ids.
-
#serial_number ⇒ Object
Returns the value of attribute serial_number.
-
#type ⇒ Object
Returns the value of attribute type.
-
#unit_id ⇒ Object
Returns the value of attribute unit_id.
-
#year ⇒ Object
Returns the value of attribute year.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EquipmentCatalogue
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EquipmentCatalogue
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::EquipmentCatalogue` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::EquipmentCatalogue`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'org_id') self.org_id = attributes[:'org_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'property_ids') if (value = attributes[:'property_ids']).is_a?(Array) self.property_ids = value end end if attributes.key?(:'json_extended_attributes') self.json_extended_attributes = attributes[:'json_extended_attributes'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'licensing_number') self.licensing_number = attributes[:'licensing_number'] end if attributes.key?(:'unit_id') self.unit_id = attributes[:'unit_id'] end if attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'current_status') self.current_status = attributes[:'current_status'] end if attributes.key?(:'current_status_date') self.current_status_date = attributes[:'current_status_date'] end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'year') self.year = attributes[:'year'] end if attributes.key?(:'manufacturer') self.manufacturer = attributes[:'manufacturer'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#current_status ⇒ Object
Returns the value of attribute current_status.
40 41 42 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 40 def current_status @current_status end |
#current_status_date ⇒ Object
Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21
43 44 45 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 43 def current_status_date @current_status_date end |
#id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
19 20 21 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 19 def id @id end |
#json_extended_attributes ⇒ Object
Returns the value of attribute json_extended_attributes.
28 29 30 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 28 def json_extended_attributes @json_extended_attributes end |
#label ⇒ Object
Returns the value of attribute label.
30 31 32 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 30 def label @label end |
#licensing_number ⇒ Object
Returns the value of attribute licensing_number.
32 33 34 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 32 def licensing_number @licensing_number end |
#manufacturer ⇒ Object
Returns the value of attribute manufacturer.
49 50 51 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 49 def manufacturer @manufacturer end |
#model ⇒ Object
Returns the value of attribute model.
45 46 47 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 45 def model @model end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 24 def name @name end |
#notes ⇒ Object
Returns the value of attribute notes.
38 39 40 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 38 def notes @notes end |
#org_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 22 def org_id @org_id end |
#property_ids ⇒ Object
Returns the value of attribute property_ids.
26 27 28 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 26 def property_ids @property_ids end |
#serial_number ⇒ Object
Returns the value of attribute serial_number.
36 37 38 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 36 def serial_number @serial_number end |
#type ⇒ Object
Returns the value of attribute type.
51 52 53 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 51 def type @type end |
#unit_id ⇒ Object
Returns the value of attribute unit_id.
34 35 36 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 34 def unit_id @unit_id end |
#year ⇒ Object
Returns the value of attribute year.
47 48 49 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 47 def year @year end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 98 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 76 def self.attribute_map { :'id' => :'id', :'org_id' => :'org_id', :'name' => :'name', :'property_ids' => :'property_ids', :'json_extended_attributes' => :'json_extended_attributes', :'label' => :'label', :'licensing_number' => :'licensing_number', :'unit_id' => :'unit_id', :'serial_number' => :'serial_number', :'notes' => :'notes', :'current_status' => :'current_status', :'current_status_date' => :'current_status_date', :'model' => :'model', :'year' => :'year', :'manufacturer' => :'manufacturer', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 312 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
131 132 133 134 135 136 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 131 def self.openapi_all_of [ :'BasicEquipmentCatalogue', :'IdentifiedModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 125 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 103 def self.openapi_types { :'id' => :'String', :'org_id' => :'String', :'name' => :'String', :'property_ids' => :'Array<String>', :'json_extended_attributes' => :'BasicExtendedAttribute', :'label' => :'String', :'licensing_number' => :'String', :'unit_id' => :'String', :'serial_number' => :'String', :'notes' => :'String', :'current_status' => :'String', :'current_status_date' => :'Time', :'model' => :'String', :'year' => :'Integer', :'manufacturer' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && org_id == o.org_id && name == o.name && property_ids == o.property_ids && json_extended_attributes == o.json_extended_attributes && label == o.label && licensing_number == o.licensing_number && unit_id == o.unit_id && serial_number == o.serial_number && notes == o.notes && current_status == o.current_status && current_status_date == o.current_status_date && model == o.model && year == o.year && manufacturer == o.manufacturer && type == o.type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 343 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 414 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 319 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
299 300 301 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 299 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
305 306 307 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 305 def hash [id, org_id, name, property_ids, json_extended_attributes, label, licensing_number, unit_id, serial_number, notes, current_status, current_status_date, model, year, manufacturer, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
222 223 224 225 226 227 228 229 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 222 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
390 391 392 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 390 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 396 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
384 385 386 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 384 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
233 234 235 236 237 238 239 240 241 242 |
# File 'lib/cropwise-platform-sdk/models/equipment_catalogue.rb', line 233 def valid? return false if @id.nil? label_validator = EnumAttributeValidator.new('String', ["EARTH_MOVING", "FORAGE_AND_HAY", "HARVESTING", "PLANTER", "SPRAYER", "TILLAGE", "TRACTOR", "TRAILER", "TRUCK", "GENERICAL_VEHICLE", "IRRIGATION", "MANURE", "MISC", "FERTILIZER", "SHOP"]) return false unless label_validator.valid?(@label) current_status_validator = EnumAttributeValidator.new('String', ["OWNER", "CONTRACTED", "LEASED", "SOLD", "JUNKED", "CONTRACT_TERMINATED", "LEASE_TERMINATED"]) return false unless current_status_validator.valid?(@current_status) type_validator = EnumAttributeValidator.new('String', ["IMPLEMENT", "VEHICLE"]) return false unless type_validator.valid?(@type) true end |