Class: CropwisePlatformSdk::FieldGeometryUpdatesApi
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::FieldGeometryUpdatesApi
- Defined in:
- lib/cropwise-platform-sdk/api/field_geometry_updates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ FieldGeometryUpdatesApi
constructor
A new instance of FieldGeometryUpdatesApi.
-
#post_fields_geometry_updates(property_id, geometry_update_request, opts = {}) ⇒ UpdateResponse
Performs field geometry updates A fields batch that can be created, updated or deleted.
-
#post_fields_geometry_updates_with_http_info(property_id, geometry_update_request, opts = {}) ⇒ Array<(UpdateResponse, Integer, Hash)>
Performs field geometry updates A fields batch that can be created, updated or deleted.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FieldGeometryUpdatesApi
Returns a new instance of FieldGeometryUpdatesApi.
19 20 21 |
# File 'lib/cropwise-platform-sdk/api/field_geometry_updates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cropwise-platform-sdk/api/field_geometry_updates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#post_fields_geometry_updates(property_id, geometry_update_request, opts = {}) ⇒ UpdateResponse
Performs field geometry updates A fields batch that can be created, updated or deleted. The request is executed asynchronously, so at the end of the request the process may not be completed.
29 30 31 32 |
# File 'lib/cropwise-platform-sdk/api/field_geometry_updates_api.rb', line 29 def post_fields_geometry_updates(property_id, geometry_update_request, opts = {}) data, _status_code, _headers = post_fields_geometry_updates_with_http_info(property_id, geometry_update_request, opts) data end |
#post_fields_geometry_updates_with_http_info(property_id, geometry_update_request, opts = {}) ⇒ Array<(UpdateResponse, Integer, Hash)>
Performs field geometry updates A fields batch that can be created, updated or deleted. The request is executed asynchronously, so at the end of the request the process may not be completed.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cropwise-platform-sdk/api/field_geometry_updates_api.rb', line 41 def post_fields_geometry_updates_with_http_info(property_id, geometry_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FieldGeometryUpdatesApi.post_fields_geometry_updates ...' end # verify the required parameter 'property_id' is set if @api_client.config.client_side_validation && property_id.nil? fail ArgumentError, "Missing the required parameter 'property_id' when calling FieldGeometryUpdatesApi.post_fields_geometry_updates" end # verify the required parameter 'geometry_update_request' is set if @api_client.config.client_side_validation && geometry_update_request.nil? fail ArgumentError, "Missing the required parameter 'geometry_update_request' when calling FieldGeometryUpdatesApi.post_fields_geometry_updates" end allowable_values = ["saved_fields"] if @api_client.config.client_side_validation && opts[:'attributes'] && !opts[:'attributes'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"attributes\", must include one of #{allowable_values}" end # resource path local_var_path = '/v2/properties/{property_id}/fields/updates'.sub('{' + 'property_id' + '}', CGI.escape(property_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'attributes'] = @api_client.build_collection_param(opts[:'attributes'], :csv) if !opts[:'attributes'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(geometry_update_request) # return_type return_type = opts[:debug_return_type] || 'UpdateResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"FieldGeometryUpdatesApi.post_fields_geometry_updates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FieldGeometryUpdatesApi#post_fields_geometry_updates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |