Class: CropwisePlatformSdk::FieldVersionDTO
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::FieldVersionDTO
- Defined in:
- lib/cropwise-platform-sdk/models/field_version_dto.rb
Instance Attribute Summary collapse
-
#calculated_area ⇒ Object
Returns the value of attribute calculated_area.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#declared_area ⇒ Object
Returns the value of attribute declared_area.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#event_date ⇒ Object
Returns the value of attribute event_date.
-
#geometry ⇒ Object
Returns the value of attribute geometry.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_modified ⇒ Object
Returns the value of attribute last_modified.
-
#name ⇒ Object
Returns the value of attribute name.
-
#parent_region_id ⇒ Object
Returns the value of attribute parent_region_id.
-
#property_id ⇒ Object
Returns the value of attribute property_id.
-
#reference_point ⇒ Object
Returns the value of attribute reference_point.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#version_id ⇒ Object
Returns the value of attribute version_id.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FieldVersionDTO
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FieldVersionDTO
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::FieldVersionDTO` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::FieldVersionDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'parent_region_id') self.parent_region_id = attributes[:'parent_region_id'] end if attributes.key?(:'property_id') self.property_id = attributes[:'property_id'] end if attributes.key?(:'calculated_area') self.calculated_area = attributes[:'calculated_area'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'declared_area') self.declared_area = attributes[:'declared_area'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'event_date') self.event_date = attributes[:'event_date'] end if attributes.key?(:'geometry') self.geometry = attributes[:'geometry'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'last_modified') self.last_modified = attributes[:'last_modified'] end if attributes.key?(:'reference_point') self.reference_point = attributes[:'reference_point'] end if attributes.key?(:'version_id') self.version_id = attributes[:'version_id'] end end |
Instance Attribute Details
#calculated_area ⇒ Object
Returns the value of attribute calculated_area.
24 25 26 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 24 def calculated_area @calculated_area end |
#created_at ⇒ Object
Returns the value of attribute created_at.
26 27 28 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 26 def created_at @created_at end |
#declared_area ⇒ Object
Returns the value of attribute declared_area.
28 29 30 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 28 def declared_area @declared_area end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
30 31 32 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 30 def deleted_at @deleted_at end |
#event_date ⇒ Object
Returns the value of attribute event_date.
32 33 34 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 32 def event_date @event_date end |
#geometry ⇒ Object
Returns the value of attribute geometry.
34 35 36 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 34 def geometry @geometry end |
#id ⇒ Object
Returns the value of attribute id.
36 37 38 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 36 def id @id end |
#last_modified ⇒ Object
Returns the value of attribute last_modified.
40 41 42 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 40 def last_modified @last_modified end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 18 def name @name end |
#parent_region_id ⇒ Object
Returns the value of attribute parent_region_id.
20 21 22 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 20 def parent_region_id @parent_region_id end |
#property_id ⇒ Object
Returns the value of attribute property_id.
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 22 def property_id @property_id end |
#reference_point ⇒ Object
Returns the value of attribute reference_point.
42 43 44 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 42 def reference_point @reference_point end |
#tags ⇒ Object
Returns the value of attribute tags.
38 39 40 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 38 def @tags end |
#version_id ⇒ Object
Returns the value of attribute version_id.
44 45 46 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 44 def version_id @version_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 67 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 47 def self.attribute_map { :'name' => :'name', :'parent_region_id' => :'parent_region_id', :'property_id' => :'property_id', :'calculated_area' => :'calculated_area', :'created_at' => :'created_at', :'declared_area' => :'declared_area', :'deleted_at' => :'deleted_at', :'event_date' => :'event_date', :'geometry' => :'geometry', :'id' => :'id', :'tags' => :'tags', :'last_modified' => :'last_modified', :'reference_point' => :'reference_point', :'version_id' => :'version_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 220 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 72 def self.openapi_types { :'name' => :'String', :'parent_region_id' => :'String', :'property_id' => :'String', :'calculated_area' => :'Float', :'created_at' => :'Time', :'declared_area' => :'Float', :'deleted_at' => :'Time', :'event_date' => :'Time', :'geometry' => :'String', :'id' => :'String', :'tags' => :'Array<String>', :'last_modified' => :'Time', :'reference_point' => :'String', :'version_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && parent_region_id == o.parent_region_id && property_id == o.property_id && calculated_area == o.calculated_area && created_at == o.created_at && declared_area == o.declared_area && deleted_at == o.deleted_at && event_date == o.event_date && geometry == o.geometry && id == o.id && == o. && last_modified == o.last_modified && reference_point == o.reference_point && version_id == o.version_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 251 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 322 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 213 def hash [name, parent_region_id, property_id, calculated_area, created_at, declared_area, deleted_at, event_date, geometry, id, , last_modified, reference_point, version_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 173 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
298 299 300 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 298 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 292 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 |
# File 'lib/cropwise-platform-sdk/models/field_version_dto.rb', line 180 def valid? true end |