Class: CropwisePlatformSdk::LegalDocumentAllOf
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::LegalDocumentAllOf
- Defined in:
- lib/cropwise-platform-sdk/models/legal_document_all_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#app ⇒ Object
Returns the value of attribute app.
-
#end_date ⇒ Object
Returns the value of attribute end_date.
-
#file_path ⇒ Object
Returns the value of attribute file_path.
-
#language ⇒ Object
Returns the value of attribute language.
-
#location ⇒ Object
Returns the value of attribute location.
-
#plan ⇒ Object
Returns the value of attribute plan.
-
#signed_document_id ⇒ Object
Returns the value of attribute signed_document_id.
-
#start_date ⇒ Object
Returns the value of attribute start_date.
-
#type_row ⇒ Object
Returns the value of attribute type_row.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LegalDocumentAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LegalDocumentAllOf
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::LegalDocumentAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::LegalDocumentAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'language') self.language = attributes[:'language'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'file_path') self.file_path = attributes[:'file_path'] end if attributes.key?(:'plan') self.plan = attributes[:'plan'] end if attributes.key?(:'app') self.app = attributes[:'app'] end if attributes.key?(:'signed_document_id') self.signed_document_id = attributes[:'signed_document_id'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'type_row') self.type_row = attributes[:'type_row'] end end |
Instance Attribute Details
#app ⇒ Object
Returns the value of attribute app.
30 31 32 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 30 def app @app end |
#end_date ⇒ Object
Returns the value of attribute end_date.
24 25 26 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 24 def end_date @end_date end |
#file_path ⇒ Object
Returns the value of attribute file_path.
26 27 28 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 26 def file_path @file_path end |
#language ⇒ Object
Returns the value of attribute language.
20 21 22 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 20 def language @language end |
#location ⇒ Object
Returns the value of attribute location.
18 19 20 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 18 def location @location end |
#plan ⇒ Object
Returns the value of attribute plan.
28 29 30 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 28 def plan @plan end |
#signed_document_id ⇒ Object
Returns the value of attribute signed_document_id.
32 33 34 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 32 def signed_document_id @signed_document_id end |
#start_date ⇒ Object
Returns the value of attribute start_date.
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 22 def start_date @start_date end |
#type_row ⇒ Object
Returns the value of attribute type_row.
36 37 38 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 36 def type_row @type_row end |
#user_id ⇒ Object
Returns the value of attribute user_id.
34 35 36 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 34 def user_id @user_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 61 def self.attribute_map { :'location' => :'location', :'language' => :'language', :'start_date' => :'startDate', :'end_date' => :'endDate', :'file_path' => :'filePath', :'plan' => :'plan', :'app' => :'app', :'signed_document_id' => :'signedDocumentId', :'user_id' => :'userId', :'type_row' => :'typeRow' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 216 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 82 def self.openapi_types { :'location' => :'String', :'language' => :'String', :'start_date' => :'Time', :'end_date' => :'Time', :'file_path' => :'String', :'plan' => :'String', :'app' => :'String', :'signed_document_id' => :'String', :'user_id' => :'String', :'type_row' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && location == o.location && language == o.language && start_date == o.start_date && end_date == o.end_date && file_path == o.file_path && plan == o.plan && app == o.app && signed_document_id == o.signed_document_id && user_id == o.user_id && type_row == o.type_row end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 247 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 318 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
203 204 205 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 203 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 209 def hash [location, language, start_date, end_date, file_path, plan, app, signed_document_id, user_id, type_row].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 161 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
294 295 296 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 294 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
288 289 290 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 288 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 |
# File 'lib/cropwise-platform-sdk/models/legal_document_all_of.rb', line 168 def valid? type_row_validator = EnumAttributeValidator.new('String', ["terms_and_conditions", "privacy_notice", "commercial_offer", "signature"]) return false unless type_row_validator.valid?(@type_row) true end |