Class: CropwisePlatformSdk::LegalDocumentsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/api/legal_documents_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ LegalDocumentsApi

Returns a new instance of LegalDocumentsApi.



19
20
21
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

Delete Legal Document Delete a legal document

Parameters:

  • legal_document_id (String)

    Numeric ID of the legal document to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 27

def delete_legal_documents_legal_document_id(legal_document_id, opts = {})
  data, _status_code, _headers = delete_legal_documents_legal_document_id_with_http_info(legal_document_id, opts)
  data
end

Delete Legal Document Delete a legal document

Parameters:

  • legal_document_id (String)

    Numeric ID of the legal document to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 37

def delete_legal_documents_legal_document_id_with_http_info(legal_document_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.delete_legal_documents_legal_document_id ...'
  end
  # verify the required parameter 'legal_document_id' is set
  if @api_client.config.client_side_validation && legal_document_id.nil?
    fail ArgumentError, "Missing the required parameter 'legal_document_id' when calling LegalDocumentsApi.delete_legal_documents_legal_document_id"
  end
  # resource path
  local_var_path = '/v2/legal_documents/{legalDocumentId}'.sub('{' + 'legalDocumentId' + '}', CGI.escape(legal_document_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteLegalDocumentsLegalDocumentId200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.delete_legal_documents_legal_document_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#delete_legal_documents_legal_document_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

List all Legal Documents Get all legal documents

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Whether deleted legal documents will be included as well. Default is 'false'

  • :size (Integer)

    Number of legal documents to return

  • :last_key (String)

    ID of the last legal document returned by the previous query

Returns:



92
93
94
95
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 92

def get_legal_documents(opts = {})
  data, _status_code, _headers = get_legal_documents_with_http_info(opts)
  data
end

List all Legal Documents Filtering by Location Get all legal documents filtering by location

Parameters:

  • location_name (String)

    The name of the location (in an two-digit country code format) to filter the legal documents

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :size (Integer)

    Number of legal documents to return

  • :last_key (String)

    ID of the last legal document returned by the previous query

  • :include_deleted (Boolean)

    Whether deleted legal documents will be included as well. Default is 'false'

Returns:



159
160
161
162
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 159

def get_legal_documents_by_location(location_name, opts = {})
  data, _status_code, _headers = get_legal_documents_by_location_with_http_info(location_name, opts)
  data
end

List all Legal Documents Filtering by Location Get all legal documents filtering by location

Parameters:

  • location_name (String)

    The name of the location (in an two-digit country code format) to filter the legal documents

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :size (Integer)

    Number of legal documents to return

  • :last_key (String)

    ID of the last legal document returned by the previous query

  • :include_deleted (Boolean)

    Whether deleted legal documents will be included as well. Default is 'false'

Returns:

  • (Array<(PageableLegalDocuments, Integer, Hash)>)

    PageableLegalDocuments data, response status code and response headers



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 172

def get_legal_documents_by_location_with_http_info(location_name, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.get_legal_documents_by_location ...'
  end
  # verify the required parameter 'location_name' is set
  if @api_client.config.client_side_validation && location_name.nil?
    fail ArgumentError, "Missing the required parameter 'location_name' when calling LegalDocumentsApi.get_legal_documents_by_location"
  end
  # resource path
  local_var_path = '/v2/legal_documents/location/{locationName}'.sub('{' + 'locationName' + '}', CGI.escape(location_name.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil?
  query_params[:'last_key'] = opts[:'last_key'] if !opts[:'last_key'].nil?
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PageableLegalDocuments'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.get_legal_documents_by_location",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#get_legal_documents_by_location\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Get Legal Document by Id Get a single legal document

Parameters:

  • legal_document_id (String)

    Numeric ID of the legal document to get

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



228
229
230
231
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 228

def get_legal_documents_legal_document_id(legal_document_id, opts = {})
  data, _status_code, _headers = get_legal_documents_legal_document_id_with_http_info(legal_document_id, opts)
  data
end

Get Legal Document by Id Get a single legal document

Parameters:

  • legal_document_id (String)

    Numeric ID of the legal document to get

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LegalDocument, Integer, Hash)>)

    LegalDocument data, response status code and response headers



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 238

def get_legal_documents_legal_document_id_with_http_info(legal_document_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.get_legal_documents_legal_document_id ...'
  end
  # verify the required parameter 'legal_document_id' is set
  if @api_client.config.client_side_validation && legal_document_id.nil?
    fail ArgumentError, "Missing the required parameter 'legal_document_id' when calling LegalDocumentsApi.get_legal_documents_legal_document_id"
  end
  # resource path
  local_var_path = '/v2/legal_documents/{legalDocumentId}'.sub('{' + 'legalDocumentId' + '}', CGI.escape(legal_document_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'LegalDocument'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.get_legal_documents_legal_document_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#get_legal_documents_legal_document_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

List all Legal Documents Get all legal documents

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Whether deleted legal documents will be included as well. Default is &#39;false&#39;

  • :size (Integer)

    Number of legal documents to return

  • :last_key (String)

    ID of the last legal document returned by the previous query

Returns:

  • (Array<(PageableLegalDocuments, Integer, Hash)>)

    PageableLegalDocuments data, response status code and response headers



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 104

def get_legal_documents_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.get_legal_documents ...'
  end
  # resource path
  local_var_path = '/v2/legal_documents/all'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?
  query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil?
  query_params[:'last_key'] = opts[:'last_key'] if !opts[:'last_key'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PageableLegalDocuments'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.get_legal_documents",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#get_legal_documents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Get all unsigned documents Get all unsigned legal documents of the current user

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location (String)

    Fetch terms and conditions, as well as privacy notice, of this two letter country code field

Returns:



291
292
293
294
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 291

def get_unsigned_legal_documents(opts = {})
  data, _status_code, _headers = get_unsigned_legal_documents_with_http_info(opts)
  data
end

Get all unsigned documents Get all unsigned legal documents of the current user

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location (String)

    Fetch terms and conditions, as well as privacy notice, of this two letter country code field

Returns:



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 301

def get_unsigned_legal_documents_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.get_unsigned_legal_documents ...'
  end
  # resource path
  local_var_path = '/v2/legal_documents/unsigned'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'location'] = opts[:'location'] if !opts[:'location'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetUnsignedLegalDocuments200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.get_unsigned_legal_documents",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#get_unsigned_legal_documents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

List User Legal Document Signatures Get all signatures of legal documents for the current user

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Whether deleted signatures will be included as well. Default is &#39;false&#39;

Returns:



351
352
353
354
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 351

def get_user_legal_documents(opts = {})
  data, _status_code, _headers = get_user_legal_documents_with_http_info(opts)
  data
end

List User Legal Document Signatures Get all signatures of legal documents for the current user

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Whether deleted signatures will be included as well. Default is &#39;false&#39;

Returns:

  • (Array<(Array<LegalDocument>, Integer, Hash)>)

    Array<LegalDocument> data, response status code and response headers



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 361

def get_user_legal_documents_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.get_user_legal_documents ...'
  end
  # resource path
  local_var_path = '/v2/legal_documents'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<LegalDocument>'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.get_user_legal_documents",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#get_user_legal_documents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_legal_documents(post_legal_documents_request, opts = {}) ⇒ LegalDocument

Create a new Legal Document Creates a new Legal Document

Parameters:

Returns:



411
412
413
414
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 411

def post_legal_documents(post_legal_documents_request, opts = {})
  data, _status_code, _headers = post_legal_documents_with_http_info(post_legal_documents_request, opts)
  data
end

#post_legal_documents_sign(opts = {}) ⇒ Array<LegalDocument>

Sign a list of Legal Documents Sign Legal Documents

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



479
480
481
482
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 479

def post_legal_documents_sign(opts = {})
  data, _status_code, _headers = post_legal_documents_sign_with_http_info(opts)
  data
end

#post_legal_documents_sign_with_http_info(opts = {}) ⇒ Array<(Array<LegalDocument>, Integer, Hash)>

Sign a list of Legal Documents Sign Legal Documents

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(Array<LegalDocument>, Integer, Hash)>)

    Array<LegalDocument> data, response status code and response headers



489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 489

def post_legal_documents_sign_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.post_legal_documents_sign ...'
  end
  # resource path
  local_var_path = '/v2/legal_documents/sign'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'post_legal_documents_sign_request_inner'])

  # return_type
  return_type = opts[:debug_return_type] || 'Array<LegalDocument>'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.post_legal_documents_sign",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#post_legal_documents_sign\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_legal_documents_with_http_info(post_legal_documents_request, opts = {}) ⇒ Array<(LegalDocument, Integer, Hash)>

Create a new Legal Document Creates a new Legal Document

Parameters:

Returns:

  • (Array<(LegalDocument, Integer, Hash)>)

    LegalDocument data, response status code and response headers



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 421

def post_legal_documents_with_http_info(post_legal_documents_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.post_legal_documents ...'
  end
  # verify the required parameter 'post_legal_documents_request' is set
  if @api_client.config.client_side_validation && post_legal_documents_request.nil?
    fail ArgumentError, "Missing the required parameter 'post_legal_documents_request' when calling LegalDocumentsApi.post_legal_documents"
  end
  # resource path
  local_var_path = '/v2/legal_documents'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(post_legal_documents_request)

  # return_type
  return_type = opts[:debug_return_type] || 'LegalDocument'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.post_legal_documents",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#post_legal_documents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Update a legal document

Parameters:

  • legal_document_id (String)

    Numeric ID of the legal document to update

  • put_legal_documents_legal_document_id_request (PutLegalDocumentsLegalDocumentIdRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



543
544
545
546
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 543

def put_legal_documents_legal_document_id(legal_document_id, put_legal_documents_legal_document_id_request, opts = {})
  data, _status_code, _headers = put_legal_documents_legal_document_id_with_http_info(legal_document_id, put_legal_documents_legal_document_id_request, opts)
  data
end

Update a legal document

Parameters:

  • legal_document_id (String)

    Numeric ID of the legal document to update

  • put_legal_documents_legal_document_id_request (PutLegalDocumentsLegalDocumentIdRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LegalDocument, Integer, Hash)>)

    LegalDocument data, response status code and response headers



553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'lib/cropwise-platform-sdk/api/legal_documents_api.rb', line 553

def put_legal_documents_legal_document_id_with_http_info(legal_document_id, put_legal_documents_legal_document_id_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LegalDocumentsApi.put_legal_documents_legal_document_id ...'
  end
  # verify the required parameter 'legal_document_id' is set
  if @api_client.config.client_side_validation && legal_document_id.nil?
    fail ArgumentError, "Missing the required parameter 'legal_document_id' when calling LegalDocumentsApi.put_legal_documents_legal_document_id"
  end
  # verify the required parameter 'put_legal_documents_legal_document_id_request' is set
  if @api_client.config.client_side_validation && put_legal_documents_legal_document_id_request.nil?
    fail ArgumentError, "Missing the required parameter 'put_legal_documents_legal_document_id_request' when calling LegalDocumentsApi.put_legal_documents_legal_document_id"
  end
  # resource path
  local_var_path = '/v2/legal_documents/{legalDocumentId}'.sub('{' + 'legalDocumentId' + '}', CGI.escape(legal_document_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(put_legal_documents_legal_document_id_request)

  # return_type
  return_type = opts[:debug_return_type] || 'LegalDocument'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"LegalDocumentsApi.put_legal_documents_legal_document_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LegalDocumentsApi#put_legal_documents_legal_document_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end