Class: CropwisePlatformSdk::NotesByNearestPointsResponseObjectAllOf
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::NotesByNearestPointsResponseObjectAllOf
- Defined in:
- lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#author ⇒ Object
Returns the value of attribute author.
-
#context ⇒ Object
A key:value collection with the format: ‘key:value/key:value/key:value/key:value/ …` There are two keywords previously defined: `field` and `property`.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#date ⇒ Object
Returns the value of attribute date.
-
#distance ⇒ Object
Returns the value of attribute distance.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#manual_location ⇒ Object
Returns the value of attribute manual_location.
-
#namespace ⇒ Object
Returns the value of attribute namespace.
-
#note ⇒ Object
Returns the value of attribute note.
-
#note_attachment ⇒ Object
Returns the value of attribute note_attachment.
-
#note_tag ⇒ Object
Returns the value of attribute note_tag.
-
#org_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#parent_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#source ⇒ Object
Returns the value of attribute source.
-
#type ⇒ Object
Returns the value of attribute type.
-
#user_location ⇒ Object
Returns the value of attribute user_location.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotesByNearestPointsResponseObjectAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ NotesByNearestPointsResponseObjectAllOf
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 137 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::NotesByNearestPointsResponseObjectAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::NotesByNearestPointsResponseObjectAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'org_id') self.org_id = attributes[:'org_id'] end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'author') self. = attributes[:'author'] end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'user_location') self.user_location = attributes[:'user_location'] end if attributes.key?(:'manual_location') self.manual_location = attributes[:'manual_location'] end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'note_attachment') if (value = attributes[:'note_attachment']).is_a?(Array) self. = value end end if attributes.key?(:'distance') self.distance = attributes[:'distance'] end if attributes.key?(:'note_tag') if (value = attributes[:'note_tag']).is_a?(Array) self.note_tag = value end end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end end |
Instance Attribute Details
#author ⇒ Object
Returns the value of attribute author.
30 31 32 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 30 def @author end |
#context ⇒ Object
A key:value collection with the format: ‘key:value/key:value/key:value/key:value/ …` There are two keywords previously defined: `field` and `property`. The app client can use any value as a key to customize.
39 40 41 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 39 def context @context end |
#created_by ⇒ Object
Returns the value of attribute created_by.
28 29 30 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 28 def created_by @created_by end |
#date ⇒ Object
Returns the value of attribute date.
34 35 36 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 34 def date @date end |
#distance ⇒ Object
Returns the value of attribute distance.
50 51 52 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 50 def distance @distance end |
#external_id ⇒ Object
Returns the value of attribute external_id.
54 55 56 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 54 def external_id @external_id end |
#id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
19 20 21 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 19 def id @id end |
#manual_location ⇒ Object
Returns the value of attribute manual_location.
43 44 45 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 43 def manual_location @manual_location end |
#namespace ⇒ Object
Returns the value of attribute namespace.
24 25 26 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 24 def namespace @namespace end |
#note ⇒ Object
Returns the value of attribute note.
32 33 34 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 32 def note @note end |
#note_attachment ⇒ Object
Returns the value of attribute note_attachment.
48 49 50 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 48 def @note_attachment end |
#note_tag ⇒ Object
Returns the value of attribute note_tag.
52 53 54 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 52 def note_tag @note_tag end |
#org_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 22 def org_id @org_id end |
#parent_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
46 47 48 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 46 def parent_id @parent_id end |
#source ⇒ Object
Returns the value of attribute source.
26 27 28 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 26 def source @source end |
#type ⇒ Object
Returns the value of attribute type.
36 37 38 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 36 def type @type end |
#user_location ⇒ Object
Returns the value of attribute user_location.
41 42 43 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 41 def user_location @user_location end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
102 103 104 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 102 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 79 def self.attribute_map { :'id' => :'id', :'org_id' => :'org_id', :'namespace' => :'namespace', :'source' => :'source', :'created_by' => :'created_by', :'author' => :'author', :'note' => :'note', :'date' => :'date', :'type' => :'type', :'context' => :'context', :'user_location' => :'user_location', :'manual_location' => :'manual_location', :'parent_id' => :'parent_id', :'note_attachment' => :'note_attachment', :'distance' => :'distance', :'note_tag' => :'note_tag', :'external_id' => :'external_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 275 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
130 131 132 133 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 130 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 107 def self.openapi_types { :'id' => :'String', :'org_id' => :'String', :'namespace' => :'String', :'source' => :'String', :'created_by' => :'String', :'author' => :'String', :'note' => :'String', :'date' => :'String', :'type' => :'NoteType', :'context' => :'String', :'user_location' => :'GeojsonObject', :'manual_location' => :'GeojsonObject', :'parent_id' => :'String', :'note_attachment' => :'Array<NoteAttachmentObject>', :'distance' => :'Float', :'note_tag' => :'Array<String>', :'external_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && org_id == o.org_id && namespace == o.namespace && source == o.source && created_by == o.created_by && == o. && note == o.note && date == o.date && type == o.type && context == o.context && user_location == o.user_location && manual_location == o.manual_location && parent_id == o.parent_id && == o. && distance == o.distance && note_tag == o.note_tag && external_id == o.external_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 306 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 377 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 282 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
262 263 264 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 262 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
268 269 270 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 268 def hash [id, org_id, namespace, source, created_by, , note, date, type, context, user_location, manual_location, parent_id, , distance, note_tag, external_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
225 226 227 228 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 225 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
353 354 355 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 353 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 359 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 347 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
232 233 234 |
# File 'lib/cropwise-platform-sdk/models/notes_by_nearest_points_response_object_all_of.rb', line 232 def valid? true end |