Class: CropwisePlatformSdk::PageableOrganizationProductsDTOAllOfContentInner
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::PageableOrganizationProductsDTOAllOfContentInner
- Defined in:
- lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#company ⇒ Object
Returns the value of attribute company.
-
#company_group ⇒ Object
Returns the value of attribute company_group.
-
#country ⇒ Object
Returns the value of attribute country.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deleted ⇒ Object
Returns the value of attribute deleted.
-
#formulation ⇒ Object
Returns the value of attribute formulation.
-
#gov_source ⇒ Object
Returns the value of attribute gov_source.
-
#id ⇒ Object
Returns the value of attribute id.
-
#indication ⇒ Object
Returns the value of attribute indication.
-
#language ⇒ Object
Returns the value of attribute language.
-
#name ⇒ Object
Returns the value of attribute name.
-
#org_id ⇒ Object
Returns the value of attribute org_id.
-
#phrases ⇒ Object
Returns the value of attribute phrases.
-
#registration_number ⇒ Object
Returns the value of attribute registration_number.
-
#selling_units ⇒ Object
Returns the value of attribute selling_units.
-
#source ⇒ Object
Returns the value of attribute source.
-
#twin_pack_code ⇒ Object
Returns the value of attribute twin_pack_code.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_any_of ⇒ Object
List of class defined in anyOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PageableOrganizationProductsDTOAllOfContentInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PageableOrganizationProductsDTOAllOfContentInner
Initializes the object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 145 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::PageableOrganizationProductsDTOAllOfContentInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::PageableOrganizationProductsDTOAllOfContentInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'indication') self.indication = attributes[:'indication'] end if attributes.key?(:'selling_units') self.selling_units = attributes[:'selling_units'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'company_group') self.company_group = attributes[:'company_group'] end if attributes.key?(:'gov_source') self.gov_source = attributes[:'gov_source'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'registration_number') self.registration_number = attributes[:'registration_number'] end if attributes.key?(:'twin_pack_code') self.twin_pack_code = attributes[:'twin_pack_code'] end if attributes.key?(:'language') self.language = attributes[:'language'] end if attributes.key?(:'phrases') if (value = attributes[:'phrases']).is_a?(Array) self.phrases = value end end if attributes.key?(:'formulation') self.formulation = attributes[:'formulation'] end if attributes.key?(:'org_id') self.org_id = attributes[:'org_id'] end end |
Instance Attribute Details
#company ⇒ Object
Returns the value of attribute company.
32 33 34 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 32 def company @company end |
#company_group ⇒ Object
Returns the value of attribute company_group.
34 35 36 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 34 def company_group @company_group end |
#country ⇒ Object
Returns the value of attribute country.
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 22 def country @country end |
#created_at ⇒ Object
Returns the value of attribute created_at.
38 39 40 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 38 def created_at @created_at end |
#deleted ⇒ Object
Returns the value of attribute deleted.
30 31 32 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 30 def deleted @deleted end |
#formulation ⇒ Object
Returns the value of attribute formulation.
50 51 52 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 50 def formulation @formulation end |
#gov_source ⇒ Object
Returns the value of attribute gov_source.
36 37 38 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 36 def gov_source @gov_source end |
#id ⇒ Object
Returns the value of attribute id.
28 29 30 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 28 def id @id end |
#indication ⇒ Object
Returns the value of attribute indication.
24 25 26 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 24 def indication @indication end |
#language ⇒ Object
Returns the value of attribute language.
46 47 48 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 46 def language @language end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 18 def name @name end |
#org_id ⇒ Object
Returns the value of attribute org_id.
52 53 54 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 52 def org_id @org_id end |
#phrases ⇒ Object
Returns the value of attribute phrases.
48 49 50 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 48 def phrases @phrases end |
#registration_number ⇒ Object
Returns the value of attribute registration_number.
42 43 44 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 42 def registration_number @registration_number end |
#selling_units ⇒ Object
Returns the value of attribute selling_units.
26 27 28 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 26 def selling_units @selling_units end |
#source ⇒ Object
Returns the value of attribute source.
20 21 22 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 20 def source @source end |
#twin_pack_code ⇒ Object
Returns the value of attribute twin_pack_code.
44 45 46 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 44 def twin_pack_code @twin_pack_code end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
40 41 42 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 40 def updated_at @updated_at end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 101 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 77 def self.attribute_map { :'name' => :'name', :'source' => :'source', :'country' => :'country', :'indication' => :'indication', :'selling_units' => :'selling_units', :'id' => :'id', :'deleted' => :'deleted', :'company' => :'company', :'company_group' => :'company_group', :'gov_source' => :'gov_source', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'registration_number' => :'registration_number', :'twin_pack_code' => :'twin_pack_code', :'language' => :'language', :'phrases' => :'phrases', :'formulation' => :'formulation', :'org_id' => :'org_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 298 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_any_of ⇒ Object
List of class defined in anyOf (OpenAPI v3)
136 137 138 139 140 141 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 136 def self.openapi_any_of [ :'CanonProductDTO', :'CustomProductDTO' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
130 131 132 133 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 130 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 106 def self.openapi_types { :'name' => :'String', :'source' => :'String', :'country' => :'String', :'indication' => :'ProductIndication', :'selling_units' => :'SellingUnits', :'id' => :'String', :'deleted' => :'Boolean', :'company' => :'String', :'company_group' => :'String', :'gov_source' => :'String', :'created_at' => :'String', :'updated_at' => :'String', :'registration_number' => :'String', :'twin_pack_code' => :'String', :'language' => :'String', :'phrases' => :'Array<PhraseDTO>', :'formulation' => :'FormulationDTO', :'org_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 260 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && source == o.source && country == o.country && indication == o.indication && selling_units == o.selling_units && id == o.id && deleted == o.deleted && company == o.company && company_group == o.company_group && gov_source == o.gov_source && created_at == o.created_at && updated_at == o.updated_at && registration_number == o.registration_number && twin_pack_code == o.twin_pack_code && language == o.language && phrases == o.phrases && formulation == o.formulation && org_id == o.org_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 329 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 400 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 305 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
285 286 287 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 285 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 291 def hash [name, source, country, indication, selling_units, id, deleted, company, company_group, gov_source, created_at, updated_at, registration_number, twin_pack_code, language, phrases, formulation, org_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
235 236 237 238 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 235 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
376 377 378 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 376 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 382 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
370 371 372 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 370 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/cropwise-platform-sdk/models/pageable_organization_products_dto_all_of_content_inner.rb', line 242 def valid? _any_of_found = false self.class.openapi_any_of.each do |_class| _any_of = CropwisePlatformSdk.const_get(_class).build_from_hash(self.to_hash) if _any_of.valid? _any_of_found = true end end if !_any_of_found return false end true end |