Class: CropwisePlatformSdk::Plan

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/models/plan.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Plan

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::Plan` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::Plan`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'app')
    self.app = attributes[:'app']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'default_duration')
    self.default_duration = attributes[:'default_duration']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'entitlements')
    if (value = attributes[:'entitlements']).is_a?(Array)
      self.entitlements = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'quotas')
    if (value = attributes[:'quotas']).is_a?(Array)
      self.quotas = value
    end
  end

  if attributes.key?(:'terms')
    if (value = attributes[:'terms']).is_a?(Array)
      self.terms = value
    end
  end

  if attributes.key?(:'valid_countries')
    if (value = attributes[:'valid_countries']).is_a?(Array)
      self.valid_countries = value
    end
  end

  if attributes.key?(:'accounts')
    if (value = attributes[:'accounts']).is_a?(Array)
      self.accounts = value
    end
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'legal_documents')
    if (value = attributes[:'legal_documents']).is_a?(Array)
      self.legal_documents = value
    end
  end
end

Instance Attribute Details

#accountsObject

Returns the value of attribute accounts.



44
45
46
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 44

def accounts
  @accounts
end

#appObject

Returns the value of attribute app.



26
27
28
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 26

def app
  @app
end

#created_atObject

Returns the value of attribute created_at.



18
19
20
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 18

def created_at
  @created_at
end

#defaultObject

Returns the value of attribute default.



28
29
30
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 28

def default
  @default
end

#default_durationObject

Returns the value of attribute default_duration.



30
31
32
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 30

def default_duration
  @default_duration
end

#deletedObject

Returns the value of attribute deleted.



32
33
34
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 32

def deleted
  @deleted
end

#entitlementsObject

Returns the value of attribute entitlements.



34
35
36
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 34

def entitlements
  @entitlements
end

#idObject

Returns the value of attribute id.



20
21
22
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 20

def id
  @id
end

Returns the value of attribute legal_documents.



48
49
50
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 48

def legal_documents
  @legal_documents
end

#locationObject

Returns the value of attribute location.



46
47
48
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 46

def location
  @location
end

#metadataObject

Returns the value of attribute metadata.



22
23
24
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 22

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



36
37
38
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 36

def name
  @name
end

#quotasObject

Returns the value of attribute quotas.



38
39
40
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 38

def quotas
  @quotas
end

#termsObject

Returns the value of attribute terms.



40
41
42
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 40

def terms
  @terms
end

#updated_atObject

Returns the value of attribute updated_at.



24
25
26
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 24

def updated_at
  @updated_at
end

#valid_countriesObject

Returns the value of attribute valid_countries.



42
43
44
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 42

def valid_countries
  @valid_countries
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 73

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 51

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'metadata' => :'metadata',
    :'updated_at' => :'updated_at',
    :'app' => :'app',
    :'default' => :'default',
    :'default_duration' => :'default_duration',
    :'deleted' => :'deleted',
    :'entitlements' => :'entitlements',
    :'name' => :'name',
    :'quotas' => :'quotas',
    :'terms' => :'terms',
    :'valid_countries' => :'valid_countries',
    :'accounts' => :'accounts',
    :'location' => :'location',
    :'legal_documents' => :'legalDocuments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 266

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



106
107
108
109
110
111
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 106

def self.openapi_all_of
  [
  :'BaseEntity',
  :'PlanAllOf'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 78

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'id' => :'String',
    :'metadata' => :'Object',
    :'updated_at' => :'Time',
    :'app' => :'String',
    :'default' => :'Boolean',
    :'default_duration' => :'Integer',
    :'deleted' => :'Boolean',
    :'entitlements' => :'Array<Entitlement>',
    :'name' => :'String',
    :'quotas' => :'Array<PlanAllOfQuotas>',
    :'terms' => :'Array<String>',
    :'valid_countries' => :'Array<String>',
    :'accounts' => :'Array<String>',
    :'location' => :'String',
    :'legal_documents' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      id == o.id &&
       == o. &&
      updated_at == o.updated_at &&
      app == o.app &&
      default == o.default &&
      default_duration == o.default_duration &&
      deleted == o.deleted &&
      entitlements == o.entitlements &&
      name == o.name &&
      quotas == o.quotas &&
      terms == o.terms &&
      valid_countries == o.valid_countries &&
      accounts == o.accounts &&
      location == o.location &&
      legal_documents == o.legal_documents
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 297

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CropwisePlatformSdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 368

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 273

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 259

def hash
  [created_at, id, , updated_at, app, default, default_duration, deleted, entitlements, name, quotas, terms, valid_countries, accounts, location, legal_documents].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 207

def list_invalid_properties
  invalid_properties = Array.new
  if @app.nil?
    invalid_properties.push('invalid value for "app", app cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 344

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



338
339
340
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 338

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
# File 'lib/cropwise-platform-sdk/models/plan.rb', line 222

def valid?
  return false if @app.nil?
  return false if @name.nil?
  true
end