Class: CropwisePlatformSdk::PolicyApi
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::PolicyApi
- Defined in:
- lib/cropwise-platform-sdk/api/policy_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_policies_by_context(context, opts = {}) ⇒ PageablePolicyDTO
Get policies by Context Get policies from context.
-
#get_policies_by_context_with_http_info(context, opts = {}) ⇒ Array<(PageablePolicyDTO, Integer, Hash)>
Get policies by Context Get policies from context.
-
#get_policy_by_context_and_id(context, policy_id, opts = {}) ⇒ PolicyDTO
Get policy by Context and Id Get policy data.
-
#get_policy_by_context_and_id_with_http_info(context, policy_id, opts = {}) ⇒ Array<(PolicyDTO, Integer, Hash)>
Get policy by Context and Id Get policy data.
-
#initialize(api_client = ApiClient.default) ⇒ PolicyApi
constructor
A new instance of PolicyApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cropwise-platform-sdk/api/policy_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_policies_by_context(context, opts = {}) ⇒ PageablePolicyDTO
Get policies by Context Get policies from context
27 28 29 30 |
# File 'lib/cropwise-platform-sdk/api/policy_api.rb', line 27 def get_policies_by_context(context, opts = {}) data, _status_code, _headers = get_policies_by_context_with_http_info(context, opts) data end |
#get_policies_by_context_with_http_info(context, opts = {}) ⇒ Array<(PageablePolicyDTO, Integer, Hash)>
Get policies by Context Get policies from context
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/cropwise-platform-sdk/api/policy_api.rb', line 37 def get_policies_by_context_with_http_info(context, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PolicyApi.get_policies_by_context ...' end # verify the required parameter 'context' is set if @api_client.config.client_side_validation && context.nil? fail ArgumentError, "Missing the required parameter 'context' when calling PolicyApi.get_policies_by_context" end # resource path local_var_path = '/v2/policies/{context}'.sub('{' + 'context' + '}', CGI.escape(context.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PageablePolicyDTO' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PolicyApi.get_policies_by_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PolicyApi#get_policies_by_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_policy_by_context_and_id(context, policy_id, opts = {}) ⇒ PolicyDTO
Get policy by Context and Id Get policy data
91 92 93 94 |
# File 'lib/cropwise-platform-sdk/api/policy_api.rb', line 91 def get_policy_by_context_and_id(context, policy_id, opts = {}) data, _status_code, _headers = get_policy_by_context_and_id_with_http_info(context, policy_id, opts) data end |
#get_policy_by_context_and_id_with_http_info(context, policy_id, opts = {}) ⇒ Array<(PolicyDTO, Integer, Hash)>
Get policy by Context and Id Get policy data
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/cropwise-platform-sdk/api/policy_api.rb', line 102 def get_policy_by_context_and_id_with_http_info(context, policy_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PolicyApi.get_policy_by_context_and_id ...' end # verify the required parameter 'context' is set if @api_client.config.client_side_validation && context.nil? fail ArgumentError, "Missing the required parameter 'context' when calling PolicyApi.get_policy_by_context_and_id" end # verify the required parameter 'policy_id' is set if @api_client.config.client_side_validation && policy_id.nil? fail ArgumentError, "Missing the required parameter 'policy_id' when calling PolicyApi.get_policy_by_context_and_id" end # resource path local_var_path = '/v2/policies/{context}/{policyId}'.sub('{' + 'context' + '}', CGI.escape(context.to_s)).sub('{' + 'policyId' + '}', CGI.escape(policy_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PolicyDTO' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PolicyApi.get_policy_by_context_and_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PolicyApi#get_policy_by_context_and_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |