Class: CropwisePlatformSdk::Property

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/models/property.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Property

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/cropwise-platform-sdk/models/property.rb', line 152

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::Property` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::Property`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'org_id')
    self.org_id = attributes[:'org_id']
  end

  if attributes.key?(:'root_region_id')
    self.root_region_id = attributes[:'root_region_id']
  end

  if attributes.key?(:'time_zone')
    self.time_zone = attributes[:'time_zone']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'zip_code')
    self.zip_code = attributes[:'zip_code']
  end

  if attributes.key?(:'place_id')
    self.place_id = attributes[:'place_id']
  end

  if attributes.key?(:'fields_updated_at')
    self.fields_updated_at = attributes[:'fields_updated_at']
  end

  if attributes.key?(:'reference_point')
    self.reference_point = attributes[:'reference_point']
  end

  if attributes.key?(:'regulatory_zone')
    self.regulatory_zone = attributes[:'regulatory_zone']
  end

  if attributes.key?(:'json_extended_attributes')
    self.json_extended_attributes = attributes[:'json_extended_attributes']
  end

  if attributes.key?(:'declared_area')
    self.declared_area = attributes[:'declared_area']
  end

  if attributes.key?(:'total_area')
    self.total_area = attributes[:'total_area']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



38
39
40
# File 'lib/cropwise-platform-sdk/models/property.rb', line 38

def address
  @address
end

#cityObject

Returns the value of attribute city.



36
37
38
# File 'lib/cropwise-platform-sdk/models/property.rb', line 36

def city
  @city
end

#countryObject

Returns the value of attribute country.



32
33
34
# File 'lib/cropwise-platform-sdk/models/property.rb', line 32

def country
  @country
end

#declared_areaObject

Area is always represented in Hectares



54
55
56
# File 'lib/cropwise-platform-sdk/models/property.rb', line 54

def declared_area
  @declared_area
end

#deletedObject

Returns the value of attribute deleted.



59
60
61
# File 'lib/cropwise-platform-sdk/models/property.rb', line 59

def deleted
  @deleted
end

#fields_updated_atObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



45
46
47
# File 'lib/cropwise-platform-sdk/models/property.rb', line 45

def fields_updated_at
  @fields_updated_at
end

#idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



20
21
22
# File 'lib/cropwise-platform-sdk/models/property.rb', line 20

def id
  @id
end

#json_extended_attributesObject

Returns the value of attribute json_extended_attributes.



51
52
53
# File 'lib/cropwise-platform-sdk/models/property.rb', line 51

def json_extended_attributes
  @json_extended_attributes
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/cropwise-platform-sdk/models/property.rb', line 22

def name
  @name
end

#org_idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



25
26
27
# File 'lib/cropwise-platform-sdk/models/property.rb', line 25

def org_id
  @org_id
end

#place_idObject

Returns the value of attribute place_id.



42
43
44
# File 'lib/cropwise-platform-sdk/models/property.rb', line 42

def place_id
  @place_id
end

#reference_pointObject

Returns the value of attribute reference_point.



47
48
49
# File 'lib/cropwise-platform-sdk/models/property.rb', line 47

def reference_point
  @reference_point
end

#regulatory_zoneObject

Returns the value of attribute regulatory_zone.



49
50
51
# File 'lib/cropwise-platform-sdk/models/property.rb', line 49

def regulatory_zone
  @regulatory_zone
end

#root_region_idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



28
29
30
# File 'lib/cropwise-platform-sdk/models/property.rb', line 28

def root_region_id
  @root_region_id
end

#stateObject

Returns the value of attribute state.



34
35
36
# File 'lib/cropwise-platform-sdk/models/property.rb', line 34

def state
  @state
end

#time_zoneObject

Returns the value of attribute time_zone.



30
31
32
# File 'lib/cropwise-platform-sdk/models/property.rb', line 30

def time_zone
  @time_zone
end

#total_areaObject

Area is always represented in Hectares



57
58
59
# File 'lib/cropwise-platform-sdk/models/property.rb', line 57

def total_area
  @total_area
end

#zip_codeObject

Returns the value of attribute zip_code.



40
41
42
# File 'lib/cropwise-platform-sdk/models/property.rb', line 40

def zip_code
  @zip_code
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/cropwise-platform-sdk/models/property.rb', line 108

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/cropwise-platform-sdk/models/property.rb', line 84

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'org_id' => :'org_id',
    :'root_region_id' => :'root_region_id',
    :'time_zone' => :'time_zone',
    :'country' => :'country',
    :'state' => :'state',
    :'city' => :'city',
    :'address' => :'address',
    :'zip_code' => :'zip_code',
    :'place_id' => :'place_id',
    :'fields_updated_at' => :'fields_updated_at',
    :'reference_point' => :'reference_point',
    :'regulatory_zone' => :'regulatory_zone',
    :'json_extended_attributes' => :'json_extended_attributes',
    :'declared_area' => :'declared_area',
    :'total_area' => :'total_area',
    :'deleted' => :'deleted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
# File 'lib/cropwise-platform-sdk/models/property.rb', line 316

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



143
144
145
146
147
148
# File 'lib/cropwise-platform-sdk/models/property.rb', line 143

def self.openapi_all_of
  [
  :'BasicProperty',
  :'IdentifiedModel'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



137
138
139
140
# File 'lib/cropwise-platform-sdk/models/property.rb', line 137

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/cropwise-platform-sdk/models/property.rb', line 113

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'org_id' => :'String',
    :'root_region_id' => :'String',
    :'time_zone' => :'TimeZone',
    :'country' => :'String',
    :'state' => :'String',
    :'city' => :'String',
    :'address' => :'String',
    :'zip_code' => :'String',
    :'place_id' => :'String',
    :'fields_updated_at' => :'Time',
    :'reference_point' => :'Point',
    :'regulatory_zone' => :'ISO3166Alpha2Code',
    :'json_extended_attributes' => :'BasicExtendedAttribute',
    :'declared_area' => :'Float',
    :'total_area' => :'Float',
    :'deleted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/cropwise-platform-sdk/models/property.rb', line 278

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      org_id == o.org_id &&
      root_region_id == o.root_region_id &&
      time_zone == o.time_zone &&
      country == o.country &&
      state == o.state &&
      city == o.city &&
      address == o.address &&
      zip_code == o.zip_code &&
      place_id == o.place_id &&
      fields_updated_at == o.fields_updated_at &&
      reference_point == o.reference_point &&
      regulatory_zone == o.regulatory_zone &&
      json_extended_attributes == o.json_extended_attributes &&
      declared_area == o.declared_area &&
      total_area == o.total_area &&
      deleted == o.deleted
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/cropwise-platform-sdk/models/property.rb', line 347

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CropwisePlatformSdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/cropwise-platform-sdk/models/property.rb', line 418

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/cropwise-platform-sdk/models/property.rb', line 323

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


303
304
305
# File 'lib/cropwise-platform-sdk/models/property.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



309
310
311
# File 'lib/cropwise-platform-sdk/models/property.rb', line 309

def hash
  [id, name, org_id, root_region_id, time_zone, country, state, city, address, zip_code, place_id, fields_updated_at, reference_point, regulatory_zone, json_extended_attributes, declared_area, total_area, deleted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/cropwise-platform-sdk/models/property.rb', line 240

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @org_id.nil?
    invalid_properties.push('invalid value for "org_id", org_id cannot be nil.')
  end

  if @time_zone.nil?
    invalid_properties.push('invalid value for "time_zone", time_zone cannot be nil.')
  end

  if @reference_point.nil?
    invalid_properties.push('invalid value for "reference_point", reference_point cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
# File 'lib/cropwise-platform-sdk/models/property.rb', line 394

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/cropwise-platform-sdk/models/property.rb', line 400

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



388
389
390
# File 'lib/cropwise-platform-sdk/models/property.rb', line 388

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
271
272
273
274
# File 'lib/cropwise-platform-sdk/models/property.rb', line 267

def valid?
  return false if @id.nil?
  return false if @name.nil?
  return false if @org_id.nil?
  return false if @time_zone.nil?
  return false if @reference_point.nil?
  true
end