Class: CropwisePlatformSdk::SeasonField

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/models/season_field.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SeasonField

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::SeasonField` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::SeasonField`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'harvesting_date')
    self.harvesting_date = attributes[:'harvesting_date']
  end

  if attributes.key?(:'planting_date')
    self.planting_date = attributes[:'planting_date']
  end

  if attributes.key?(:'emergency_date')
    self.emergency_date = attributes[:'emergency_date']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'varieties_ids')
    if (value = attributes[:'varieties_ids']).is_a?(Array)
      self.varieties_ids = value
    end
  end

  if attributes.key?(:'json_extended_attributes')
    self.json_extended_attributes = attributes[:'json_extended_attributes']
  end

  if attributes.key?(:'property_id')
    self.property_id = attributes[:'property_id']
  end

  if attributes.key?(:'season_id')
    self.season_id = attributes[:'season_id']
  end
end

Instance Attribute Details

#emergency_dateObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



29
30
31
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 29

def emergency_date
  @emergency_date
end

#end_dateObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



35
36
37
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 35

def end_date
  @end_date
end

#harvesting_dateObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



23
24
25
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 23

def harvesting_date
  @harvesting_date
end

#idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



20
21
22
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 20

def id
  @id
end

#json_extended_attributesObject

Returns the value of attribute json_extended_attributes.



39
40
41
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 39

def json_extended_attributes
  @json_extended_attributes
end

#planting_dateObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



26
27
28
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 26

def planting_date
  @planting_date
end

#property_idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



42
43
44
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 42

def property_id
  @property_id
end

#season_idObject

A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).



45
46
47
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 45

def season_id
  @season_id
end

#start_dateObject

Full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21



32
33
34
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 32

def start_date
  @start_date
end

#varieties_idsObject

Returns the value of attribute varieties_ids.



37
38
39
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 37

def varieties_ids
  @varieties_ids
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 64

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 48

def self.attribute_map
  {
    :'id' => :'id',
    :'harvesting_date' => :'harvesting_date',
    :'planting_date' => :'planting_date',
    :'emergency_date' => :'emergency_date',
    :'start_date' => :'start_date',
    :'end_date' => :'end_date',
    :'varieties_ids' => :'varieties_ids',
    :'json_extended_attributes' => :'json_extended_attributes',
    :'property_id' => :'property_id',
    :'season_id' => :'season_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 217

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



91
92
93
94
95
96
97
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 91

def self.openapi_all_of
  [
  :'BasicSeasonField',
  :'IdentifiedModel',
  :'SeasonFieldAllOf'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'harvesting_date' => :'Time',
    :'planting_date' => :'Time',
    :'emergency_date' => :'Time',
    :'start_date' => :'Time',
    :'end_date' => :'Time',
    :'varieties_ids' => :'Array<String>',
    :'json_extended_attributes' => :'BasicExtendedAttribute',
    :'property_id' => :'String',
    :'season_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      harvesting_date == o.harvesting_date &&
      planting_date == o.planting_date &&
      emergency_date == o.emergency_date &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      varieties_ids == o.varieties_ids &&
      json_extended_attributes == o.json_extended_attributes &&
      property_id == o.property_id &&
      season_id == o.season_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 248

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CropwisePlatformSdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 319

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 224

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 210

def hash
  [id, harvesting_date, planting_date, emergency_date, start_date, end_date, varieties_ids, json_extended_attributes, property_id, season_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 159

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @end_date.nil?
    invalid_properties.push('invalid value for "end_date", end_date cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 295

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



289
290
291
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 289

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
# File 'lib/cropwise-platform-sdk/models/season_field.rb', line 178

def valid?
  return false if @id.nil?
  return false if @start_date.nil?
  return false if @end_date.nil?
  true
end