Class: CropwisePlatformSdk::StoreApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/api/store_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ StoreApi

Returns a new instance of StoreApi.



19
20
21
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_store_app_by_id(app_id, workspace_id, opts = {}) ⇒ BasicApp

Get App By Id in Store Get App By Id in Store

Parameters:

  • app_id (String)
  • workspace_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_expired_contracts (Boolean)

    Search for App in Store with expired contract

Returns:



29
30
31
32
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 29

def get_store_app_by_id(app_id, workspace_id, opts = {})
  data, _status_code, _headers = get_store_app_by_id_with_http_info(app_id, workspace_id, opts)
  data
end

#get_store_app_by_id_with_http_info(app_id, workspace_id, opts = {}) ⇒ Array<(BasicApp, Integer, Hash)>

Get App By Id in Store Get App By Id in Store

Parameters:

  • app_id (String)
  • workspace_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_expired_contracts (Boolean)

    Search for App in Store with expired contract

Returns:

  • (Array<(BasicApp, Integer, Hash)>)

    BasicApp data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 41

def get_store_app_by_id_with_http_info(app_id, workspace_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StoreApi.get_store_app_by_id ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling StoreApi.get_store_app_by_id"
  end
  # verify the required parameter 'workspace_id' is set
  if @api_client.config.client_side_validation && workspace_id.nil?
    fail ArgumentError, "Missing the required parameter 'workspace_id' when calling StoreApi.get_store_app_by_id"
  end
  # resource path
  local_var_path = '/v2/store/apps/{app_id}'.sub('{' + 'app_id' + '}', CGI.escape(app_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'workspace_id'] = workspace_id
  query_params[:'include_expired_contracts'] = opts[:'include_expired_contracts'] if !opts[:'include_expired_contracts'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BasicApp'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"StoreApi.get_store_app_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StoreApi#get_store_app_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_store_apps(opts = {}) ⇒ PagedBasicApp

List Apps in Store List Apps in Store

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Requested page number. Starting from zero. Default is zero.

  • :size (Integer)

    Requested page size. Default is unpaged

  • :workspace_id (String)
  • :filter_by_language (String)

    Filter apps by accept-language header. Default true

Returns:



103
104
105
106
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 103

def get_store_apps(opts = {})
  data, _status_code, _headers = get_store_apps_with_http_info(opts)
  data
end

#get_store_apps_per_workspace(opts = {}) ⇒ PagedStorePerWorkspace

List Apps in Store per workspace List Apps in Store per workspace, for all the workspaces with at least one organization.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Requested page number. Starting from zero. Default is zero.

  • :size (Integer)

    Requested page size. Default is unpaged

  • :filter_by_language (Boolean)

    Filter apps by accept-language header. Default true

  • :include_default_workspace (Boolean)

    Includes the default workspace on the response, even if it doesn&#39;t have an org. Default false

  • :include_unpublished (Boolean)

    Returns unpublished apps as well as published ones. Default false

Returns:



173
174
175
176
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 173

def get_store_apps_per_workspace(opts = {})
  data, _status_code, _headers = get_store_apps_per_workspace_with_http_info(opts)
  data
end

#get_store_apps_per_workspace_with_http_info(opts = {}) ⇒ Array<(PagedStorePerWorkspace, Integer, Hash)>

List Apps in Store per workspace List Apps in Store per workspace, for all the workspaces with at least one organization.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Requested page number. Starting from zero. Default is zero.

  • :size (Integer)

    Requested page size. Default is unpaged

  • :filter_by_language (Boolean)

    Filter apps by accept-language header. Default true

  • :include_default_workspace (Boolean)

    Includes the default workspace on the response, even if it doesn&#39;t have an org. Default false

  • :include_unpublished (Boolean)

    Returns unpublished apps as well as published ones. Default false

Returns:

  • (Array<(PagedStorePerWorkspace, Integer, Hash)>)

    PagedStorePerWorkspace data, response status code and response headers



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 187

def get_store_apps_per_workspace_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StoreApi.get_store_apps_per_workspace ...'
  end
  # resource path
  local_var_path = '/v2/store/workspaces/apps'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil?
  query_params[:'filter_by_language'] = opts[:'filter_by_language'] if !opts[:'filter_by_language'].nil?
  query_params[:'include_default_workspace'] = opts[:'include_default_workspace'] if !opts[:'include_default_workspace'].nil?
  query_params[:'include_unpublished'] = opts[:'include_unpublished'] if !opts[:'include_unpublished'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PagedStorePerWorkspace'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"StoreApi.get_store_apps_per_workspace",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StoreApi#get_store_apps_per_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_store_apps_with_http_info(opts = {}) ⇒ Array<(PagedBasicApp, Integer, Hash)>

List Apps in Store List Apps in Store

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Requested page number. Starting from zero. Default is zero.

  • :size (Integer)

    Requested page size. Default is unpaged

  • :workspace_id (String)
  • :filter_by_language (String)

    Filter apps by accept-language header. Default true

Returns:

  • (Array<(PagedBasicApp, Integer, Hash)>)

    PagedBasicApp data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/cropwise-platform-sdk/api/store_api.rb', line 116

def get_store_apps_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StoreApi.get_store_apps ...'
  end
  # resource path
  local_var_path = '/v2/store/apps'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil?
  query_params[:'workspace_id'] = opts[:'workspace_id'] if !opts[:'workspace_id'].nil?
  query_params[:'filter_by_language'] = opts[:'filter_by_language'] if !opts[:'filter_by_language'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PagedBasicApp'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"StoreApi.get_store_apps",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StoreApi#get_store_apps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end