Class: CropwisePlatformSdk::VarietyApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cropwise-platform-sdk/api/variety_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ VarietyApi

Returns a new instance of VarietyApi.



19
20
21
# File 'lib/cropwise-platform-sdk/api/variety_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cropwise-platform-sdk/api/variety_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_variesties(opts = {}) ⇒ PagedVariety

List varieties List Varieties

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Requested page number. Starting from zero. Default is zero.

  • :size (Integer)

    Requested page size. Default is unpaged

  • :accept_language (String)

    Variety names will be responded in the chosen language

Returns:



29
30
31
32
# File 'lib/cropwise-platform-sdk/api/variety_api.rb', line 29

def get_variesties(opts = {})
  data, _status_code, _headers = get_variesties_with_http_info(opts)
  data
end

#get_variesties_with_http_info(opts = {}) ⇒ Array<(PagedVariety, Integer, Hash)>

List varieties List Varieties

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Requested page number. Starting from zero. Default is zero.

  • :size (Integer)

    Requested page size. Default is unpaged

  • :accept_language (String)

    Variety names will be responded in the chosen language

Returns:

  • (Array<(PagedVariety, Integer, Hash)>)

    PagedVariety data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/cropwise-platform-sdk/api/variety_api.rb', line 41

def get_variesties_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VarietyApi.get_variesties ...'
  end
  # resource path
  local_var_path = '/v2/varieties'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PagedVariety'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"VarietyApi.get_variesties",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VarietyApi#get_variesties\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end