Class: CropwisePlatformSdk::VouchersApi
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::VouchersApi
- Defined in:
- lib/cropwise-platform-sdk/api/vouchers_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_vouchers_voucher_id(voucher_id, opts = {}) ⇒ DeleteVouchersVoucherId200Response
Delete Voucher by appId Removes a single voucher.
-
#delete_vouchers_voucher_id_with_http_info(voucher_id, opts = {}) ⇒ Array<(DeleteVouchersVoucherId200Response, Integer, Hash)>
Delete Voucher by appId Removes a single voucher.
-
#get_campaign_vouchers_campaign_id(campaign_id, opts = {}) ⇒ PageableVouchers
Get Campaign Vouchers Get all vouchers from a campaign.
-
#get_campaign_vouchers_campaign_id_with_http_info(campaign_id, opts = {}) ⇒ Array<(PageableVouchers, Integer, Hash)>
Get Campaign Vouchers Get all vouchers from a campaign.
-
#get_vouchers_voucher_id(voucher_id, opts = {}) ⇒ Voucher
Get Voucher By Id Get a single voucher.
-
#get_vouchers_voucher_id_redeem_info(voucher_id, opts = {}) ⇒ GetVouchersVoucherIdRedeemInfo200Response
Get All Plans from a Voucher Get the redeem info that a voucher entitles.
-
#get_vouchers_voucher_id_redeem_info_with_http_info(voucher_id, opts = {}) ⇒ Array<(GetVouchersVoucherIdRedeemInfo200Response, Integer, Hash)>
Get All Plans from a Voucher Get the redeem info that a voucher entitles.
-
#get_vouchers_voucher_id_with_http_info(voucher_id, opts = {}) ⇒ Array<(Voucher, Integer, Hash)>
Get Voucher By Id Get a single voucher.
-
#initialize(api_client = ApiClient.default) ⇒ VouchersApi
constructor
A new instance of VouchersApi.
-
#post_campaign_vouchers_campaign_id(campaign_id, post_campaign_vouchers_campaign_id_request, opts = {}) ⇒ Array<Voucher>
Add Vouchers to Campaign Add vouchers to a campaign.
-
#post_campaign_vouchers_campaign_id_with_http_info(campaign_id, post_campaign_vouchers_campaign_id_request, opts = {}) ⇒ Array<(Array<Voucher>, Integer, Hash)>
Add Vouchers to Campaign Add vouchers to a campaign.
-
#post_vouchers(voucher, opts = {}) ⇒ Voucher
Create Voucher Creates a new voucher.
-
#post_vouchers_with_http_info(voucher, opts = {}) ⇒ Array<(Voucher, Integer, Hash)>
Create Voucher Creates a new voucher.
-
#put_vouchers_voucher_id(voucher_id, put_vouchers_voucher_id_request, opts = {}) ⇒ Voucher
Edit Voucher by ID Updates a single voucher.
-
#put_vouchers_voucher_id_with_http_info(voucher_id, put_vouchers_voucher_id_request, opts = {}) ⇒ Array<(Voucher, Integer, Hash)>
Edit Voucher by ID Updates a single voucher.
-
#redeem_voucher(redeem_voucher_request, opts = {}) ⇒ RedeemVoucherResponse
Redeem Voucher Redeem a voucher.
-
#redeem_voucher_with_http_info(redeem_voucher_request, opts = {}) ⇒ Array<(RedeemVoucherResponse, Integer, Hash)>
Redeem Voucher Redeem a voucher.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ VouchersApi
Returns a new instance of VouchersApi.
19 20 21 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_vouchers_voucher_id(voucher_id, opts = {}) ⇒ DeleteVouchersVoucherId200Response
Delete Voucher by appId Removes a single voucher
27 28 29 30 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 27 def delete_vouchers_voucher_id(voucher_id, opts = {}) data, _status_code, _headers = delete_vouchers_voucher_id_with_http_info(voucher_id, opts) data end |
#delete_vouchers_voucher_id_with_http_info(voucher_id, opts = {}) ⇒ Array<(DeleteVouchersVoucherId200Response, Integer, Hash)>
Delete Voucher by appId Removes a single voucher
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 37 def delete_vouchers_voucher_id_with_http_info(voucher_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.delete_vouchers_voucher_id ...' end # verify the required parameter 'voucher_id' is set if @api_client.config.client_side_validation && voucher_id.nil? fail ArgumentError, "Missing the required parameter 'voucher_id' when calling VouchersApi.delete_vouchers_voucher_id" end # resource path local_var_path = '/v2/vouchers/{voucherId}'.sub('{' + 'voucherId' + '}', CGI.escape(voucher_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteVouchersVoucherId200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.delete_vouchers_voucher_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#delete_vouchers_voucher_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_campaign_vouchers_campaign_id(campaign_id, opts = {}) ⇒ PageableVouchers
Get Campaign Vouchers Get all vouchers from a campaign
92 93 94 95 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 92 def get_campaign_vouchers_campaign_id(campaign_id, opts = {}) data, _status_code, _headers = get_campaign_vouchers_campaign_id_with_http_info(campaign_id, opts) data end |
#get_campaign_vouchers_campaign_id_with_http_info(campaign_id, opts = {}) ⇒ Array<(PageableVouchers, Integer, Hash)>
Get Campaign Vouchers Get all vouchers from a campaign
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 104 def get_campaign_vouchers_campaign_id_with_http_info(campaign_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.get_campaign_vouchers_campaign_id ...' end # verify the required parameter 'campaign_id' is set if @api_client.config.client_side_validation && campaign_id.nil? fail ArgumentError, "Missing the required parameter 'campaign_id' when calling VouchersApi.get_campaign_vouchers_campaign_id" end # resource path local_var_path = '/v2/campaigns/{campaignId}/vouchers'.sub('{' + 'campaignId' + '}', CGI.escape(campaign_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'last_key'] = opts[:'last_key'] if !opts[:'last_key'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PageableVouchers' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.get_campaign_vouchers_campaign_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#get_campaign_vouchers_campaign_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_vouchers_voucher_id(voucher_id, opts = {}) ⇒ Voucher
Get Voucher By Id Get a single voucher
159 160 161 162 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 159 def get_vouchers_voucher_id(voucher_id, opts = {}) data, _status_code, _headers = get_vouchers_voucher_id_with_http_info(voucher_id, opts) data end |
#get_vouchers_voucher_id_redeem_info(voucher_id, opts = {}) ⇒ GetVouchersVoucherIdRedeemInfo200Response
Get All Plans from a Voucher Get the redeem info that a voucher entitles
223 224 225 226 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 223 def get_vouchers_voucher_id_redeem_info(voucher_id, opts = {}) data, _status_code, _headers = get_vouchers_voucher_id_redeem_info_with_http_info(voucher_id, opts) data end |
#get_vouchers_voucher_id_redeem_info_with_http_info(voucher_id, opts = {}) ⇒ Array<(GetVouchersVoucherIdRedeemInfo200Response, Integer, Hash)>
Get All Plans from a Voucher Get the redeem info that a voucher entitles
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 234 def get_vouchers_voucher_id_redeem_info_with_http_info(voucher_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.get_vouchers_voucher_id_redeem_info ...' end # verify the required parameter 'voucher_id' is set if @api_client.config.client_side_validation && voucher_id.nil? fail ArgumentError, "Missing the required parameter 'voucher_id' when calling VouchersApi.get_vouchers_voucher_id_redeem_info" end # resource path local_var_path = '/v2/vouchers/{voucherId}/redeem-info'.sub('{' + 'voucherId' + '}', CGI.escape(voucher_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'include_app_basic_info'] = opts[:'include_app_basic_info'] if !opts[:'include_app_basic_info'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetVouchersVoucherIdRedeemInfo200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.get_vouchers_voucher_id_redeem_info", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#get_vouchers_voucher_id_redeem_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_vouchers_voucher_id_with_http_info(voucher_id, opts = {}) ⇒ Array<(Voucher, Integer, Hash)>
Get Voucher By Id Get a single voucher
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 169 def get_vouchers_voucher_id_with_http_info(voucher_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.get_vouchers_voucher_id ...' end # verify the required parameter 'voucher_id' is set if @api_client.config.client_side_validation && voucher_id.nil? fail ArgumentError, "Missing the required parameter 'voucher_id' when calling VouchersApi.get_vouchers_voucher_id" end # resource path local_var_path = '/v2/vouchers/{voucherId}'.sub('{' + 'voucherId' + '}', CGI.escape(voucher_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Voucher' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.get_vouchers_voucher_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#get_vouchers_voucher_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_campaign_vouchers_campaign_id(campaign_id, post_campaign_vouchers_campaign_id_request, opts = {}) ⇒ Array<Voucher>
Add Vouchers to Campaign Add vouchers to a campaign
289 290 291 292 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 289 def post_campaign_vouchers_campaign_id(campaign_id, post_campaign_vouchers_campaign_id_request, opts = {}) data, _status_code, _headers = post_campaign_vouchers_campaign_id_with_http_info(campaign_id, post_campaign_vouchers_campaign_id_request, opts) data end |
#post_campaign_vouchers_campaign_id_with_http_info(campaign_id, post_campaign_vouchers_campaign_id_request, opts = {}) ⇒ Array<(Array<Voucher>, Integer, Hash)>
Add Vouchers to Campaign Add vouchers to a campaign
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 300 def post_campaign_vouchers_campaign_id_with_http_info(campaign_id, post_campaign_vouchers_campaign_id_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.post_campaign_vouchers_campaign_id ...' end # verify the required parameter 'campaign_id' is set if @api_client.config.client_side_validation && campaign_id.nil? fail ArgumentError, "Missing the required parameter 'campaign_id' when calling VouchersApi.post_campaign_vouchers_campaign_id" end # verify the required parameter 'post_campaign_vouchers_campaign_id_request' is set if @api_client.config.client_side_validation && post_campaign_vouchers_campaign_id_request.nil? fail ArgumentError, "Missing the required parameter 'post_campaign_vouchers_campaign_id_request' when calling VouchersApi.post_campaign_vouchers_campaign_id" end # resource path local_var_path = '/v2/campaigns/{campaignId}/vouchers'.sub('{' + 'campaignId' + '}', CGI.escape(campaign_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(post_campaign_vouchers_campaign_id_request) # return_type return_type = opts[:debug_return_type] || 'Array<Voucher>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.post_campaign_vouchers_campaign_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#post_campaign_vouchers_campaign_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_vouchers(voucher, opts = {}) ⇒ Voucher
Create Voucher Creates a new voucher
362 363 364 365 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 362 def post_vouchers(voucher, opts = {}) data, _status_code, _headers = post_vouchers_with_http_info(voucher, opts) data end |
#post_vouchers_with_http_info(voucher, opts = {}) ⇒ Array<(Voucher, Integer, Hash)>
Create Voucher Creates a new voucher
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 372 def post_vouchers_with_http_info(voucher, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.post_vouchers ...' end # verify the required parameter 'voucher' is set if @api_client.config.client_side_validation && voucher.nil? fail ArgumentError, "Missing the required parameter 'voucher' when calling VouchersApi.post_vouchers" end # resource path local_var_path = '/v2/vouchers' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(voucher) # return_type return_type = opts[:debug_return_type] || 'Voucher' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.post_vouchers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#post_vouchers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_vouchers_voucher_id(voucher_id, put_vouchers_voucher_id_request, opts = {}) ⇒ Voucher
Edit Voucher by ID Updates a single voucher
431 432 433 434 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 431 def put_vouchers_voucher_id(voucher_id, put_vouchers_voucher_id_request, opts = {}) data, _status_code, _headers = put_vouchers_voucher_id_with_http_info(voucher_id, put_vouchers_voucher_id_request, opts) data end |
#put_vouchers_voucher_id_with_http_info(voucher_id, put_vouchers_voucher_id_request, opts = {}) ⇒ Array<(Voucher, Integer, Hash)>
Edit Voucher by ID Updates a single voucher
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 442 def put_vouchers_voucher_id_with_http_info(voucher_id, put_vouchers_voucher_id_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.put_vouchers_voucher_id ...' end # verify the required parameter 'voucher_id' is set if @api_client.config.client_side_validation && voucher_id.nil? fail ArgumentError, "Missing the required parameter 'voucher_id' when calling VouchersApi.put_vouchers_voucher_id" end # verify the required parameter 'put_vouchers_voucher_id_request' is set if @api_client.config.client_side_validation && put_vouchers_voucher_id_request.nil? fail ArgumentError, "Missing the required parameter 'put_vouchers_voucher_id_request' when calling VouchersApi.put_vouchers_voucher_id" end # resource path local_var_path = '/v2/vouchers/{voucherId}'.sub('{' + 'voucherId' + '}', CGI.escape(voucher_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(put_vouchers_voucher_id_request) # return_type return_type = opts[:debug_return_type] || 'Voucher' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.put_vouchers_voucher_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#put_vouchers_voucher_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redeem_voucher(redeem_voucher_request, opts = {}) ⇒ RedeemVoucherResponse
Redeem Voucher Redeem a voucher
504 505 506 507 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 504 def redeem_voucher(redeem_voucher_request, opts = {}) data, _status_code, _headers = redeem_voucher_with_http_info(redeem_voucher_request, opts) data end |
#redeem_voucher_with_http_info(redeem_voucher_request, opts = {}) ⇒ Array<(RedeemVoucherResponse, Integer, Hash)>
Redeem Voucher Redeem a voucher
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/cropwise-platform-sdk/api/vouchers_api.rb', line 514 def redeem_voucher_with_http_info(redeem_voucher_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VouchersApi.redeem_voucher ...' end # verify the required parameter 'redeem_voucher_request' is set if @api_client.config.client_side_validation && redeem_voucher_request.nil? fail ArgumentError, "Missing the required parameter 'redeem_voucher_request' when calling VouchersApi.redeem_voucher" end # resource path local_var_path = '/v2/vouchers/redeem' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(redeem_voucher_request) # return_type return_type = opts[:debug_return_type] || 'RedeemVoucherResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"VouchersApi.redeem_voucher", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VouchersApi#redeem_voucher\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |