Class: CropwisePlatformSdk::BasicOrganizationAllOf
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::BasicOrganizationAllOf
- Defined in:
- lib/cropwise-platform-sdk/models/basic_organization_all_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#deleted ⇒ Object
Returns the value of attribute deleted.
-
#email ⇒ Object
Returns the value of attribute email.
-
#employer_identification_number ⇒ Object
Returns the value of attribute employer_identification_number.
-
#json_extended_attributes ⇒ Object
Returns the value of attribute json_extended_attributes.
-
#licensing_account_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#phone ⇒ Object
E.164 international phone number formatting.
-
#picture_url ⇒ Object
Returns the value of attribute picture_url.
-
#place_id ⇒ Object
Returns the value of attribute place_id.
-
#reference_point ⇒ Object
Returns the value of attribute reference_point.
-
#state ⇒ Object
Returns the value of attribute state.
-
#unit_system ⇒ Object
Returns the value of attribute unit_system.
-
#workspace_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
-
#zip_code ⇒ Object
Returns the value of attribute zip_code.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BasicOrganizationAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BasicOrganizationAllOf
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CropwisePlatformSdk::BasicOrganizationAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CropwisePlatformSdk::BasicOrganizationAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'zip_code') self.zip_code = attributes[:'zip_code'] end if attributes.key?(:'place_id') self.place_id = attributes[:'place_id'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'employer_identification_number') self.employer_identification_number = attributes[:'employer_identification_number'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'unit_system') self.unit_system = attributes[:'unit_system'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'reference_point') self.reference_point = attributes[:'reference_point'] end if attributes.key?(:'picture_url') self.picture_url = attributes[:'picture_url'] end if attributes.key?(:'json_extended_attributes') self.json_extended_attributes = attributes[:'json_extended_attributes'] end if attributes.key?(:'licensing_account_id') self.licensing_account_id = attributes[:'licensing_account_id'] end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
18 19 20 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 18 def address @address end |
#city ⇒ Object
Returns the value of attribute city.
20 21 22 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 20 def city @city end |
#country ⇒ Object
Returns the value of attribute country.
24 25 26 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 24 def country @country end |
#currency ⇒ Object
Returns the value of attribute currency.
37 38 39 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 37 def currency @currency end |
#deleted ⇒ Object
Returns the value of attribute deleted.
41 42 43 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 41 def deleted @deleted end |
#email ⇒ Object
Returns the value of attribute email.
33 34 35 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 33 def email @email end |
#employer_identification_number ⇒ Object
Returns the value of attribute employer_identification_number.
35 36 37 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 35 def employer_identification_number @employer_identification_number end |
#json_extended_attributes ⇒ Object
Returns the value of attribute json_extended_attributes.
47 48 49 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 47 def json_extended_attributes @json_extended_attributes end |
#licensing_account_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
50 51 52 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 50 def licensing_account_id @licensing_account_id end |
#phone ⇒ Object
E.164 international phone number formatting
31 32 33 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 31 def phone @phone end |
#picture_url ⇒ Object
Returns the value of attribute picture_url.
45 46 47 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 45 def picture_url @picture_url end |
#place_id ⇒ Object
Returns the value of attribute place_id.
28 29 30 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 28 def place_id @place_id end |
#reference_point ⇒ Object
Returns the value of attribute reference_point.
43 44 45 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 43 def reference_point @reference_point end |
#state ⇒ Object
Returns the value of attribute state.
22 23 24 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 22 def state @state end |
#unit_system ⇒ Object
Returns the value of attribute unit_system.
39 40 41 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 39 def unit_system @unit_system end |
#workspace_id ⇒ Object
A v4 UUID, represented in its canonical textual form (hexadecimal, lowercase, 8-4-4-4-12 groups separated by a dash (-)).
53 54 55 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 53 def workspace_id @workspace_id end |
#zip_code ⇒ Object
Returns the value of attribute zip_code.
26 27 28 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 26 def zip_code @zip_code end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 101 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 78 def self.attribute_map { :'address' => :'address', :'city' => :'city', :'state' => :'state', :'country' => :'country', :'zip_code' => :'zip_code', :'place_id' => :'place_id', :'phone' => :'phone', :'email' => :'email', :'employer_identification_number' => :'employer_identification_number', :'currency' => :'currency', :'unit_system' => :'unit_system', :'deleted' => :'deleted', :'reference_point' => :'reference_point', :'picture_url' => :'picture_url', :'json_extended_attributes' => :'json_extended_attributes', :'licensing_account_id' => :'licensing_account_id', :'workspace_id' => :'workspace_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 309 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
129 130 131 132 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 129 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 106 def self.openapi_types { :'address' => :'String', :'city' => :'String', :'state' => :'String', :'country' => :'String', :'zip_code' => :'String', :'place_id' => :'String', :'phone' => :'String', :'email' => :'String', :'employer_identification_number' => :'String', :'currency' => :'String', :'unit_system' => :'String', :'deleted' => :'Boolean', :'reference_point' => :'Point', :'picture_url' => :'String', :'json_extended_attributes' => :'BasicExtendedAttribute', :'licensing_account_id' => :'String', :'workspace_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && address == o.address && city == o.city && state == o.state && country == o.country && zip_code == o.zip_code && place_id == o.place_id && phone == o.phone && email == o.email && employer_identification_number == o.employer_identification_number && currency == o.currency && unit_system == o.unit_system && deleted == o.deleted && reference_point == o.reference_point && picture_url == o.picture_url && json_extended_attributes == o.json_extended_attributes && licensing_account_id == o.licensing_account_id && workspace_id == o.workspace_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 340 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CropwisePlatformSdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 411 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 316 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 302 def hash [address, city, state, country, zip_code, place_id, phone, email, employer_identification_number, currency, unit_system, deleted, reference_point, picture_url, json_extended_attributes, licensing_account_id, workspace_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 220 def list_invalid_properties invalid_properties = Array.new if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @unit_system.nil? invalid_properties.push('invalid value for "unit_system", unit_system cannot be nil.') end if @workspace_id.nil? invalid_properties.push('invalid value for "workspace_id", workspace_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
387 388 389 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 387 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
381 382 383 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 381 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
239 240 241 242 243 244 245 246 247 248 |
# File 'lib/cropwise-platform-sdk/models/basic_organization_all_of.rb', line 239 def valid? return false if @currency.nil? currency_validator = EnumAttributeValidator.new('String', ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BOV", "BRL", "BSD", "BTN", "BWP", "BYN", "BZD", "CAD", "CDF", "CHE", "CHF", "CHW", "CLF", "CLP", "CNY", "COP", "COU", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "INR", "IQD", "IRR", "ISK", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRU", "MUR", "MVR", "MWK", "MXN", "MXV", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SRD", "SSP", "STN", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TWD", "TZS", "UAH", "UGX", "USD", "USN", "UYI", "UYU", "UYW", "UZS", "VES", "VND", "VUV", "WST", "XAF", "XAG", "XAU", "XBA", "XBB", "XBC", "XBD", "XCD", "XDR", "XOF", "XPD", "XPF", "XPT", "XSU", "XTS", "XUA", "XXX", "YER", "ZAR", "ZMW", "ZWL"]) return false unless currency_validator.valid?(@currency) return false if @unit_system.nil? unit_system_validator = EnumAttributeValidator.new('String', ["METRIC", "IMPERIAL"]) return false unless unit_system_validator.valid?(@unit_system) return false if @workspace_id.nil? true end |