Class: CropwisePlatformSdk::BillingApi
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::BillingApi
- Defined in:
- lib/cropwise-platform-sdk/api/billing_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#confirmate_contract_payment_id(workspace_id, contract_id, opts = {}) ⇒ nil
Confirmate a Contract Payment Confirmate a Contract Payment.
-
#confirmate_contract_payment_id_with_http_info(workspace_id, contract_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Confirmate a Contract Payment Confirmate a Contract Payment.
-
#create_payment_intent_by_id(workspace_id, opts = {}) ⇒ PaymentIntent
Create a Payment Intent Create a Payment Id and Returns the Payment URL.
-
#create_payment_intent_by_id_with_http_info(workspace_id, opts = {}) ⇒ Array<(PaymentIntent, Integer, Hash)>
Create a Payment Intent Create a Payment Id and Returns the Payment URL.
-
#initialize(api_client = ApiClient.default) ⇒ BillingApi
constructor
A new instance of BillingApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BillingApi
Returns a new instance of BillingApi.
19 20 21 |
# File 'lib/cropwise-platform-sdk/api/billing_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cropwise-platform-sdk/api/billing_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#confirmate_contract_payment_id(workspace_id, contract_id, opts = {}) ⇒ nil
Confirmate a Contract Payment Confirmate a Contract Payment.
28 29 30 31 |
# File 'lib/cropwise-platform-sdk/api/billing_api.rb', line 28 def confirmate_contract_payment_id(workspace_id, contract_id, opts = {}) confirmate_contract_payment_id_with_http_info(workspace_id, contract_id, opts) nil end |
#confirmate_contract_payment_id_with_http_info(workspace_id, contract_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Confirmate a Contract Payment Confirmate a Contract Payment.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cropwise-platform-sdk/api/billing_api.rb', line 39 def confirmate_contract_payment_id_with_http_info(workspace_id, contract_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingApi.confirmate_contract_payment_id ...' end # verify the required parameter 'workspace_id' is set if @api_client.config.client_side_validation && workspace_id.nil? fail ArgumentError, "Missing the required parameter 'workspace_id' when calling BillingApi.confirmate_contract_payment_id" end # verify the required parameter 'contract_id' is set if @api_client.config.client_side_validation && contract_id.nil? fail ArgumentError, "Missing the required parameter 'contract_id' when calling BillingApi.confirmate_contract_payment_id" end # resource path local_var_path = '/v2/billing/workspaces/{workspace_id}/contracts/{contract_id}/confirmation'.sub('{' + 'workspace_id' + '}', CGI.escape(workspace_id.to_s)).sub('{' + 'contract_id' + '}', CGI.escape(contract_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"BillingApi.confirmate_contract_payment_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingApi#confirmate_contract_payment_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_payment_intent_by_id(workspace_id, opts = {}) ⇒ PaymentIntent
Create a Payment Intent Create a Payment Id and Returns the Payment URL.
97 98 99 100 |
# File 'lib/cropwise-platform-sdk/api/billing_api.rb', line 97 def create_payment_intent_by_id(workspace_id, opts = {}) data, _status_code, _headers = create_payment_intent_by_id_with_http_info(workspace_id, opts) data end |
#create_payment_intent_by_id_with_http_info(workspace_id, opts = {}) ⇒ Array<(PaymentIntent, Integer, Hash)>
Create a Payment Intent Create a Payment Id and Returns the Payment URL.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/cropwise-platform-sdk/api/billing_api.rb', line 108 def create_payment_intent_by_id_with_http_info(workspace_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingApi.create_payment_intent_by_id ...' end # verify the required parameter 'workspace_id' is set if @api_client.config.client_side_validation && workspace_id.nil? fail ArgumentError, "Missing the required parameter 'workspace_id' when calling BillingApi.create_payment_intent_by_id" end # resource path local_var_path = '/v2/billing/workspaces/{workspace_id}/intent'.sub('{' + 'workspace_id' + '}', CGI.escape(workspace_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'intent_confirmation']) # return_type return_type = opts[:debug_return_type] || 'PaymentIntent' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"BillingApi.create_payment_intent_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingApi#create_payment_intent_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |