Class: CropwisePlatformSdk::EquipmentApi
- Inherits:
-
Object
- Object
- CropwisePlatformSdk::EquipmentApi
- Defined in:
- lib/cropwise-platform-sdk/api/equipment_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_equipment_by_id(id, opts = {}) ⇒ nil
Delete the specified Equipment.
-
#delete_equipment_by_id_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete the specified Equipment.
-
#get_equipment_by_id(id, opts = {}) ⇒ EquipmentCatalogue
List Equipment By ID List Equipment.
-
#get_equipment_by_id_with_http_info(id, opts = {}) ⇒ Array<(EquipmentCatalogue, Integer, Hash)>
List Equipment By ID List Equipment.
-
#get_equipments(org_id, opts = {}) ⇒ PagedEquipment
List Organization equipments List Organization Equipments.
-
#get_equipments_by_equipments_id(opts = {}) ⇒ PagedEquipment
Get Equipments by Ids Get Equipments by its Ids.
-
#get_equipments_by_equipments_id_with_http_info(opts = {}) ⇒ Array<(PagedEquipment, Integer, Hash)>
Get Equipments by Ids Get Equipments by its Ids.
-
#get_equipments_with_extended_attribute(org_id, include_extended, opts = {}) ⇒ PagedEquipment
List Organization equipments with filtered extra_attribute List Organization Equipments with ExtendedAttribute.
-
#get_equipments_with_extended_attribute_with_http_info(org_id, include_extended, opts = {}) ⇒ Array<(PagedEquipment, Integer, Hash)>
List Organization equipments with filtered extra_attribute List Organization Equipments with ExtendedAttribute.
-
#get_equipments_with_http_info(org_id, opts = {}) ⇒ Array<(PagedEquipment, Integer, Hash)>
List Organization equipments List Organization Equipments.
-
#initialize(api_client = ApiClient.default) ⇒ EquipmentApi
constructor
A new instance of EquipmentApi.
-
#post_v2_equipments(opts = {}) ⇒ EquipmentCatalogue
Equipment Creator Creates equipments for organizations.
-
#post_v2_equipments_with_http_info(opts = {}) ⇒ Array<(EquipmentCatalogue, Integer, Hash)>
Equipment Creator Creates equipments for organizations.
-
#update_equipment_by_id(id, opts = {}) ⇒ EquipmentCatalogue
Update Equipment Update Equipment.
-
#update_equipment_by_id_with_http_info(id, opts = {}) ⇒ Array<(EquipmentCatalogue, Integer, Hash)>
Update Equipment Update Equipment.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EquipmentApi
Returns a new instance of EquipmentApi.
19 20 21 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_equipment_by_id(id, opts = {}) ⇒ nil
Delete the specified Equipment.
27 28 29 30 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 27 def delete_equipment_by_id(id, opts = {}) delete_equipment_by_id_with_http_info(id, opts) nil end |
#delete_equipment_by_id_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete the specified Equipment.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 37 def delete_equipment_by_id_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.delete_equipment_by_id ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EquipmentApi.delete_equipment_by_id" end # resource path local_var_path = '/v2/equipments/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.delete_equipment_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#delete_equipment_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_equipment_by_id(id, opts = {}) ⇒ EquipmentCatalogue
List Equipment By ID List Equipment
88 89 90 91 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 88 def get_equipment_by_id(id, opts = {}) data, _status_code, _headers = get_equipment_by_id_with_http_info(id, opts) data end |
#get_equipment_by_id_with_http_info(id, opts = {}) ⇒ Array<(EquipmentCatalogue, Integer, Hash)>
List Equipment By ID List Equipment
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 98 def get_equipment_by_id_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.get_equipment_by_id ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EquipmentApi.get_equipment_by_id" end # resource path local_var_path = '/v2/equipments/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EquipmentCatalogue' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.get_equipment_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#get_equipment_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_equipments(org_id, opts = {}) ⇒ PagedEquipment
List Organization equipments List Organization Equipments
156 157 158 159 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 156 def get_equipments(org_id, opts = {}) data, _status_code, _headers = get_equipments_with_http_info(org_id, opts) data end |
#get_equipments_by_equipments_id(opts = {}) ⇒ PagedEquipment
Get Equipments by Ids Get Equipments by its Ids. If an id does not exist, it does not return it.
233 234 235 236 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 233 def get_equipments_by_equipments_id(opts = {}) data, _status_code, _headers = get_equipments_by_equipments_id_with_http_info(opts) data end |
#get_equipments_by_equipments_id_with_http_info(opts = {}) ⇒ Array<(PagedEquipment, Integer, Hash)>
Get Equipments by Ids Get Equipments by its Ids. If an id does not exist, it does not return it.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 247 def get_equipments_by_equipments_id_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.get_equipments_by_equipments_id ...' end allowable_values = [] if @api_client.config.client_side_validation && opts[:'type'] && !opts[:'type'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"type\", must include one of #{allowable_values}" end # resource path local_var_path = '/v2/equipments/ids' # query parameters query_params = opts[:query_params] || {} query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'type'] = @api_client.build_collection_param(opts[:'type'], :multi) if !opts[:'type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'uuid_list_model']) # return_type return_type = opts[:debug_return_type] || 'PagedEquipment' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.get_equipments_by_equipments_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#get_equipments_by_equipments_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_equipments_with_extended_attribute(org_id, include_extended, opts = {}) ⇒ PagedEquipment
List Organization equipments with filtered extra_attribute List Organization Equipments with ExtendedAttribute
317 318 319 320 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 317 def get_equipments_with_extended_attribute(org_id, include_extended, opts = {}) data, _status_code, _headers = get_equipments_with_extended_attribute_with_http_info(org_id, include_extended, opts) data end |
#get_equipments_with_extended_attribute_with_http_info(org_id, include_extended, opts = {}) ⇒ Array<(PagedEquipment, Integer, Hash)>
List Organization equipments with filtered extra_attribute List Organization Equipments with ExtendedAttribute
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 335 def get_equipments_with_extended_attribute_with_http_info(org_id, include_extended, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.get_equipments_with_extended_attribute ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling EquipmentApi.get_equipments_with_extended_attribute" end # verify the required parameter 'include_extended' is set if @api_client.config.client_side_validation && include_extended.nil? fail ArgumentError, "Missing the required parameter 'include_extended' when calling EquipmentApi.get_equipments_with_extended_attribute" end # resource path local_var_path = '/v2/orgs/{org_id}/equipments/extended-search'.sub('{' + 'org_id' + '}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'include_extended'] = include_extended query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? query_params[:'extra_attribute'] = opts[:'extra_attribute'] if !opts[:'extra_attribute'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'client-id'] = opts[:'client_id'] if !opts[:'client_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedEquipment' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.get_equipments_with_extended_attribute", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#get_equipments_with_extended_attribute\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_equipments_with_http_info(org_id, opts = {}) ⇒ Array<(PagedEquipment, Integer, Hash)>
List Organization equipments List Organization Equipments
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 171 def get_equipments_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.get_equipments ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling EquipmentApi.get_equipments" end # resource path local_var_path = '/v2/orgs/{org_id}/equipments'.sub('{' + 'org_id' + '}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'size'] = opts[:'size'] if !opts[:'size'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PagedEquipment' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.get_equipments", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#get_equipments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_v2_equipments(opts = {}) ⇒ EquipmentCatalogue
Equipment Creator Creates equipments for organizations
401 402 403 404 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 401 def post_v2_equipments(opts = {}) data, _status_code, _headers = post_v2_equipments_with_http_info(opts) data end |
#post_v2_equipments_with_http_info(opts = {}) ⇒ Array<(EquipmentCatalogue, Integer, Hash)>
Equipment Creator Creates equipments for organizations
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 412 def post_v2_equipments_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.post_v2_equipments ...' end # resource path local_var_path = '/v2/equipments' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'client-id'] = opts[:'client_id'] if !opts[:'client_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'basic_equipment_catalogue']) # return_type return_type = opts[:debug_return_type] || 'EquipmentCatalogue' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.post_v2_equipments", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#post_v2_equipments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_equipment_by_id(id, opts = {}) ⇒ EquipmentCatalogue
Update Equipment Update Equipment
469 470 471 472 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 469 def update_equipment_by_id(id, opts = {}) data, _status_code, _headers = update_equipment_by_id_with_http_info(id, opts) data end |
#update_equipment_by_id_with_http_info(id, opts = {}) ⇒ Array<(EquipmentCatalogue, Integer, Hash)>
Update Equipment Update Equipment
481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/cropwise-platform-sdk/api/equipment_api.rb', line 481 def update_equipment_by_id_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EquipmentApi.update_equipment_by_id ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EquipmentApi.update_equipment_by_id" end # resource path local_var_path = '/v2/equipments/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'client-id'] = opts[:'client_id'] if !opts[:'client_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'equipment_catalogue']) # return_type return_type = opts[:debug_return_type] || 'EquipmentCatalogue' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EquipmentApi.update_equipment_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EquipmentApi#update_equipment_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |